@@ -318,25 +318,30 @@ int AContainer::remove( const Widget *v )
   return 0;
 }
 
+class SpecialLimits
+{
+public:
+  SpecialLimits()
+  {
+    min = max = -1;
+  }
+  
+  int min, max;
+};
+
 int AContainer::resize( int nw, int nh )
 {
   int *mins, *maxs, *weights, *erg;
   int i, ew, t1, t2;
-  int *specialMinWidth, *specialMaxWidth, *specialMinHeight, *specialMaxHeight;
   bool repeatScale;
   int realContWidth, realContHeight;
   int v, j;
   bool *contDone;
 
-  specialMinWidth = new int[xelems];
-  specialMaxWidth = new int[xelems];
-  specialMinHeight = new int[yelems];
-  specialMaxHeight = new int[yelems];
+  SpecialLimits *specialWidths, *specialHeights;
 
-  for ( i = 0; i < xelems; i++ ) specialMinWidth[i] = -1;
-  for ( i = 0; i < xelems; i++ ) specialMaxWidth[i] = -1;
-  for ( i = 0; i < yelems; i++ ) specialMinHeight[i] = -1;
-  for ( i = 0; i < yelems; i++ ) specialMaxHeight[i] = -1;
+  specialWidths = new SpecialLimits[xelems];
+  specialHeights = new SpecialLimits[yelems];
 
   contDone = new bool[xelems * yelems * 2 * 2];
   for ( i = 0; i < ( xelems * yelems * 2 * 2 ); i++ ) contDone[i] = false;
@@ -372,8 +377,8 @@ int AContainer::resize( int nw, int nh )
 	if ( v > t1 ) t1 = v;
       }
       
-      if ( specialMinWidth[i] > t1 ) {
-	t1 = specialMinWidth[i];
+      if ( specialWidths[i].min > t1 ) {
+	t1 = specialWidths[i].min;
       }
       
       t2 = -1;
@@ -385,10 +390,10 @@ int AContainer::resize( int nw, int nh )
 	}
       }
       
-      if ( specialMaxWidth[i] > 0 ) {
+      if ( specialWidths[i].max > 0 ) {
         if ( ( t2 == -1 ) ||
-	     ( specialMaxWidth[i] < t2 ) ) {
-	  t2 = specialMaxWidth[i];
+	     ( specialWidths[i].max < t2 ) ) {
+	  t2 = specialWidths[i].max;
         }
       }
       
@@ -446,8 +451,8 @@ int AContainer::resize( int nw, int nh )
 	if ( v > t1 ) t1 = v;
       }
       
-      if ( specialMinHeight[i] > t1 ) {
-	t1 = specialMinHeight[i];
+      if ( specialHeights[i].min > t1 ) {
+	t1 = specialHeights[i].min;
       }
       
       t2 = -1;
@@ -459,10 +464,10 @@ int AContainer::resize( int nw, int nh )
 	}
       }
 
-      if ( specialMaxHeight[i] > 0 ) {
+      if ( specialHeights[i].max > 0 ) {
         if ( ( t2 == -1 ) ||
-	     ( specialMaxHeight[i] < t2 ) ) {
-	  t2 = specialMaxHeight[i];
+	     ( specialHeights[i].max < t2 ) ) {
+	  t2 = specialHeights[i].max;
         }
       }
 
@@ -513,41 +518,78 @@ int AContainer::resize( int nw, int nh )
 	   *         and we give it more space in the next try
 	   *         but it will than use less
 	   */
+          /* new method: we start with no limits (-1) and set min/max
+           * if any container doesn't use the requested size
+           * after setting min and max they are only allowed to grow
+           * so there is enough space for the largest container
+           */
+          
 	  if ( realContWidth > t1 ) {
-	    if ( realContWidth > specialMinWidth[i % xelems] ) {
-	      specialMinWidth[i % xelems] = realContWidth;
-	      if ( contDone[i] == false ) {
-		repeatScale = true;
-	      }
-	      contDone[i] = true;
+            // cont needs more width than given
+            // raise min and max values
+	    if ( realContWidth > specialWidths[i % xelems].min ) {
+              specialWidths[i % xelems].min = realContWidth;
+              
+              // check whether min is now larger than max and raise max in this case
+              if ( specialWidths[i % xelems].max < realContWidth &&
+                   specialWidths[i % xelems].max >= 0 ) {
+                specialWidths[i % xelems].max = realContWidth;
+              }
+              
+              if ( contDone[4 * i] == false ) {
+                repeatScale = true;
+              }
+              contDone[4 * i] = true;
 	    }
 	  } else if ( realContWidth < t1 ) {
-	    if ( ( specialMaxWidth[i % xelems] < 0 ) ||
-		 ( realContWidth < specialMaxWidth[i % xelems] ) ) {
-	      specialMaxWidth[i % xelems] = realContWidth;
-	      if ( contDone[i + 1] == false ) {
-		repeatScale = true;
-	      }
-	      contDone[i + 1] = true;
-	    }
+            // cont uses less than given
+            // set max
+	    if ( realContWidth > specialWidths[i % xelems].max ) {
+              specialWidths[i % xelems].max = realContWidth;
+              
+              // if it's not less than current min
+              if ( specialWidths[i % xelems].max < specialWidths[i % xelems].min ) {
+                specialWidths[i % xelems].max = specialWidths[i % xelems].min;
+              }
+              
+              if ( contDone[4 * i + 1] == false ) {
+                repeatScale = true;
+              }
+              contDone[4 * i + 1] = true;
+            }
 	  }
 
 	  if ( realContHeight > t2 ) {
-	    if ( realContHeight > specialMinHeight[i / xelems] ) {
-	      specialMinHeight[i / xelems] = realContHeight;
-	      if ( contDone[i + 2] == false ) {
-		repeatScale = true;
-	      }
-	      contDone[i + 2] = true;
+            // cont needs more height than given
+            // raise min and max values
+	    if ( realContHeight > specialHeights[i / xelems].min ) {
+              specialHeights[i / xelems].min = realContHeight;
+              
+              if ( specialHeights[i / xelems].max < realContHeight &&
+                   specialHeights[i / xelems].max >= 0 ) {
+                specialHeights[i / xelems].max = realContHeight;
+              }
+
+              if ( contDone[4 * i + 2] == false ) {
+                repeatScale = true;
+              }
+              contDone[4 * i + 2] = true;
 	    }
 	  } else if ( realContHeight < t2 ) {
-	    if ( ( specialMaxHeight[i / xelems] < 0 ) ||
-		 ( realContHeight < specialMaxHeight[i / xelems] ) ) {
-	      specialMaxHeight[i / xelems] = realContHeight;
-	      if ( contDone[i + 3] == false ) {
-		repeatScale = true;
-	      }
-	      contDone[i + 3] = true;
+            // cont uses less than given
+            // set max
+	    if ( realContHeight > specialHeights[i / xelems].max ) {
+              specialHeights[i / xelems].max = realContHeight;
+             
+              // if it's not less than current min
+              if ( specialHeights[i / xelems].max < specialHeights[i / xelems].min ) {
+                specialHeights[i / xelems].max = specialHeights[i / xelems].min;
+              }
+ 
+              if ( contDone[4 * i + 3] == false ) {
+                repeatScale = true;
+              }
+              contDone[4 * i + 3] = true;
 	    }
 	  }
 	}
@@ -555,12 +597,9 @@ int AContainer::resize( int nw, int nh )
     }
   }
 
-  delete [] specialMinWidth;
-  delete [] specialMaxWidth;
-  delete [] specialMinHeight;
-  delete [] specialMaxHeight;
-
   delete [] contDone;
+  delete [] specialWidths;
+  delete [] specialHeights;
 
   return 0;
 }
