@@ -1,6 +1,6 @@
 /* aguix.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2006 Ralf Hoffmann.
+ * Copyright (C) 2001-2007 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,13 +18,13 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: aguix.cc,v 1.77 2005/12/06 20:59:42 ralf Exp $ */
 
 #include "aguix.h"
 #include "awindow.h"
 #include <locale.h>
 #include "utf8.hh"
 #include "drawablecont.hh"
+#include <algorithm>
 
 #ifdef USE_AGUIXTIMER
 #include <signal.h>
@@ -105,6 +105,7 @@ void AGUIX_im_dest_callback( XIM callim, XPointer client_data, XPointer call_dat
 #endif //USE_XIM
 
 long AGUIX::timerEvent = 0;
+std::map<std::string,int> AGUIX::_colors_for_widgets;
 
 #ifdef USE_AGUIXTIMER
 void aguix_timer( int s )
@@ -126,9 +127,6 @@ AGUIX::AGUIX()
   mainfont=NULL;
   dsp=NULL;
   colors=0;
-  wins=new List();
-  messages=new List();
-  fonts=new List();
   privatecmap=false;
   cutstart=NULL;
   cutbuffer=NULL;
@@ -269,9 +267,6 @@ AGUIX::~AGUIX()
   }
   cancelCut();
   if(cutbuffer!=NULL) _freesafe(cutbuffer);
-  delete wins;
-  delete messages;
-  delete fonts;
   _freesafe( keybuf );
 }
 
@@ -284,13 +279,12 @@ void AGUIX::panic(const char *msg)
 void AGUIX::closeX()
 {
   destroyGroupWin();
-  int id=fonts->initEnum();
-  AGUIXFont *tf=(AGUIXFont*)fonts->getFirstElement(id);
-  while(tf!=NULL) {
-    delete tf;
-    tf=(AGUIXFont*)fonts->getNextElement(id);
+
+  while ( fonts.empty() == false ) {
+      AGUIXFont *tf = fonts.front();
+      fonts.pop_front();
+      delete tf;
   }
-  fonts->closeEnum(id);
   if(classname!=NULL) _freesafe(classname);
 
   while ( colors > 0 ) {
@@ -537,7 +531,7 @@ Atom *AGUIX::getCloseAtom()
 void AGUIX::insertWindow(AWindow *win)
 {
   if(win==NULL) return;
-  wins->addElement(win);
+  wins.push_back( win );
 
   if ( win->isTopLevel() == true ) {
     setTransientWindow( win );
@@ -547,19 +541,16 @@ void AGUIX::insertWindow(AWindow *win)
 void AGUIX::removeWindow(AWindow *win)
 {
   if(win==NULL) return;
-  wins->removeElement(win);
+  wins.remove( win );
   if ( win == transientwindow ) {
-    AWindow *new_transient_win = NULL, *win_id;
-    int id = wins->initEnum();
+    AWindow *new_transient_win = NULL;
 
-    win_id = (AWindow*)wins->getFirstElement( id );
-    while ( win_id != NULL ) {
-      if ( win_id->isTopLevel() == true ) {
-        new_transient_win = win_id;
-      }
-      win_id = (AWindow*)wins->getNextElement( id );
+    for ( wins_cit_t it1 = wins.begin(); it1 != wins.end(); it1++ ) {
+        AWindow *win_id = *it1;
+        if ( win_id->isTopLevel() == true ) {
+            new_transient_win = win_id;
+        }
     }
-    wins->closeEnum( id );
     
     setTransientWindow( new_transient_win );
   }
@@ -573,7 +564,6 @@ Message *AGUIX::wait4mess( int mode )
   AWindow *msgawin;
 #ifdef USE_XIM
   Window msgwin;
-  int id;
   Status status;
 #endif
   
@@ -585,17 +575,16 @@ Message *AGUIX::wait4mess( int mode )
 #ifdef USE_XIM
   switch ( LastEvent.type ) {
     case KeyPress:
-      id = wins->initEnum();
       msgwin = LastEvent.xkey.window;
-      
-      msgawin = (AWindow*)wins->getFirstElement( id );
-      while ( msgawin != NULL ) {
-	if ( msgawin->isTopLevel() == true ) {
-	  if ( msgawin->isParent( msgwin, false ) == true ) break;
-	}
-	msgawin = (AWindow*)wins->getNextElement( id );
+
+      msgawin = NULL;
+      for ( wins_cit_t it1 = wins.begin(); it1 != wins.end(); it1++ ) {
+          msgawin = *it1;
+          if ( msgawin->isTopLevel() == true ) {
+              if ( msgawin->isParent( msgwin, false ) == true ) break;
+          }
+          msgawin = NULL;
       }
-      wins->closeEnum( id );
       break;
     default:
       msgawin = NULL;
@@ -936,10 +925,10 @@ AGMessage *AGUIX::GetMessage(AWindow *parent)
 
 AGMessage *AGUIX::WaitMessage(AWindow *parent)
 {
-  while(messages->size()==0) {
-    msgHandler( MES_WAIT, parent, false );
-  }
-  return getAGMsg();
+    while ( messages.empty() == true ) {
+        msgHandler( MES_WAIT, parent, false );
+    }
+    return getAGMsg();
 }
 
 void AGUIX::copyArea(Drawable source,Drawable dest,int s_x,int s_y,int width,int height,int d_x,int d_y)
@@ -975,28 +964,26 @@ bool AGUIX::ReactMessage(Message *msg,AWindow *parent)
   // als erstes das Fenster ausfindig machen
   // dann ReactMessage des Fenster aufrufen
   bool returnvalue=false;
-  AWindow *win;
   if ( ( msg->type == ClientMessage ) &&
        ( msg->specialType == Message::NONE ) ) {
     return returnvalue;
   }
-  int id;
-  id=wins->initEnum();
   while ( msg->loop < 2 ) {
-    win=(AWindow*)wins->getFirstElement(id);
-    while((win!=NULL)&&(returnvalue==false)) {
-      if((parent==NULL)||(msg->type==Expose)) {
-	returnvalue = win->handleMessage( &LastEvent, msg );
-      } else {
-	if(parent->isParent(win->getWindow(),false)==true) {
-	  returnvalue = win->handleMessage( &LastEvent, msg );
-	}
+      for ( wins_cit_t it1 = wins.begin();
+            ( it1 != wins.end() ) && ( returnvalue == false );
+            it1++ ) {
+          AWindow *win = *it1;
+          if ( ( parent == NULL ) || ( msg->type == Expose ) ) {
+              returnvalue = win->handleMessage( &LastEvent, msg );
+          } else {
+              if ( parent->isParent( win->getWindow(), false ) == true ) {
+                  returnvalue = win->handleMessage( &LastEvent, msg );
+              }
+          }
+          // with lockElement don't quit this loop
+          if ( msg->lockElement != NULL ) returnvalue = false;
       }
-      // with lockElement don't quit this loop
-      if ( msg->lockElement != NULL ) returnvalue = false;
-      win=(AWindow*)wins->getNextElement(id);
-    }
-    
+
     if ( msg->lockElement != NULL ) {
       // there is a lock element
       // check whether the element accepted this msg
@@ -1017,7 +1004,6 @@ bool AGUIX::ReactMessage(Message *msg,AWindow *parent)
     }
     msg->loop++;
   }
-  wins->closeEnum(id);
   return returnvalue;
 }
 
@@ -1038,14 +1024,17 @@ char **AGUIX::getargv() const
 
 void AGUIX::putAGMsg(AGMessage *msg)
 {
-  messages->addElement(msg);
+    messages.push_back( msg );
 }
 
 AGMessage *AGUIX::getAGMsg()
 {
-  AGMessage *msg=(AGMessage*)messages->getFirstElement();
-  messages->removeFirstElement();
-  return msg;
+    if ( messages.empty() == true )
+        return NULL;
+    
+    AGMessage *msg = messages.front();
+    messages.pop_front();
+    return msg;
 }
 
 void AGUIX::ReplyMessage(AGMessage *msg)
@@ -1122,16 +1111,15 @@ int AGUIX::changeColor(int index2,int red,int green,int blue)
 
 AGUIXFont *AGUIX::getFont( const char *name )
 {
-  int id;
-  AGUIXFont *tf;
+  AGUIXFont *tf = NULL;
 
-  id = fonts->initEnum();
-  tf = (AGUIXFont*)fonts->getFirstElement( id );
-  while ( tf != NULL ) {
-    if ( strcmp( tf->getName(), name ) == 0 ) break;
-    tf = (AGUIXFont*)fonts->getNextElement( id );
+  for ( aguixfont_list_cit_t it1 = fonts.begin();
+        it1 != fonts.end();
+        it1++ ) {
+      tf = *it1;
+      if ( strcmp( tf->getName(), name ) == 0 ) break;
+      tf = NULL;
   }
-  fonts->closeEnum( id );
 
   if ( tf == NULL ) {
     tf = new AGUIXFont( this );
@@ -1139,38 +1127,37 @@ AGUIXFont *AGUIX::getFont( const char *name )
       delete tf;
       return NULL;
     }
-    fonts->addElement( tf );
+    fonts.push_back( tf );
   }
   return tf;
 }
 
 void AGUIX::ExposeHandler(Message *msg)
 {
-  AWindow *win;
-  int id;
-  if(msg->window!=0) {
-    id=wins->initEnum();
-    win=(AWindow*)wins->getFirstElement(id);
-    while(win!=NULL) {
-      if(msg->type==Expose) {
-        win->handleMessage(&LastEvent,msg);
+  if ( msg->window != 0 ) {
+      for ( wins_cit_t it1 = wins.begin();
+            it1 != wins.end();
+            it1++ ) {
+          AWindow *win = *it1;
+          if ( msg->type == Expose ) {
+              win->handleMessage( &LastEvent, msg );
+          }
       }
-      win=(AWindow*)wins->getNextElement(id);
-    }
-    wins->closeEnum(id);
   }
 }
 
 AWindow *AGUIX::findAWindow(Window win)
 {
-  AWindow *awin;
-  int id=wins->initEnum();
-  awin=(AWindow*)wins->getFirstElement(id);
-  while(awin!=NULL) {
-    if(awin->isParent(win,true)==true) break;
-    awin=(AWindow*)wins->getNextElement(id);
+  AWindow *awin = NULL;
+
+  for ( wins_cit_t it1 = wins.begin();
+        it1 != wins.end();
+        it1++ ) {
+      awin = *it1;
+      if ( awin->isParent( win, true ) == true ) break;
+      awin = NULL;
   }
-  wins->closeEnum(id);
+  
   return awin;
 }
 
@@ -1314,8 +1301,6 @@ void
 AGUIX::changeColormap()
 {
   Colormap newcmap;
-  int id;
-  AWindow *win;
   if(privatecmap==false) {
 #ifdef DEBUG
     printf("go to private cmap\n");
@@ -1323,13 +1308,13 @@ AGUIX::changeColormap()
     newcmap=XCopyColormapAndFree(dsp,cmap);
     cmap=newcmap;
     privatecmap=true;
-    id=wins->initEnum();
-    win=(AWindow*)wins->getFirstElement(id);
-    while(win!=NULL) {
-      XSetWindowColormap(dsp,win->getWindow(),cmap);
-      win=(AWindow*)wins->getNextElement(id);
+
+    for ( wins_cit_t it1 = wins.begin();
+          it1 != wins.end();
+          it1++ ) {
+        AWindow *win = *it1;
+        XSetWindowColormap( dsp, win->getWindow(), cmap );
     }
-    wins->closeEnum(id);
   }
 }
 
@@ -1995,8 +1980,8 @@ void AGUIX::doXMsgs( int mode, AWindow *parent, bool onlyexpose )
 
 bool AGUIX::noMoreMessages() const
 {
-  if ( messages->size() == 0 ) return true;
-  return false;
+    if ( messages.empty() == true ) return true;
+    return false;
 }
 
 #ifdef USE_XIM
@@ -2015,8 +2000,6 @@ int AGUIX::openIM()
   XIMStyle supported_styles, style;
   XIMStyles *im_supported_styles;
   int i;
-  int id;
-  AWindow *awin;
   
   inputmethod = XOpenIM( dsp, NULL, NULL, NULL );
   if ( inputmethod == NULL ) {
@@ -2055,13 +2038,11 @@ int AGUIX::openIM()
       fprintf( stderr, "Worker Warning: Wanted inputstyle not available\n");
 #endif
     } else {
-      id = wins->initEnum();
-      awin = (AWindow*)wins->getFirstElement( id );
-      while ( awin != NULL ) {
-	awin->createXIC();
-	awin = (AWindow*)wins->getNextElement( id );
-      }
-      wins->closeEnum( id );
+        for ( wins_cit_t it1 = wins.begin();
+              it1 != wins.end();
+              it1++ ) {
+            (*it1)->createXIC();
+        }
     }
     XFree( im_supported_styles );
   }
@@ -2070,17 +2051,12 @@ int AGUIX::openIM()
 
 void AGUIX::closeIM()
 {
-  int id;
-  AWindow *awin;
-
-  id = wins->initEnum();
-  awin = (AWindow*)wins->getFirstElement( id );
-  while ( awin != NULL ) {
-    awin->closeXIC();
-    awin = (AWindow*)wins->getNextElement( id );
+  for ( wins_cit_t it1 = wins.begin();
+        it1 != wins.end();
+        it1++ ) {
+      (*it1)->closeXIC();
   }
-  wins->closeEnum( id );
-
+      
   im_style = 0;
   if ( inputmethod != NULL ) {
     XCloseIM( inputmethod );
@@ -2100,19 +2076,14 @@ void AGUIX::IMInstCallback( Display *calldsp )
 
 void AGUIX::IMDestCallback()
 {
-  int id;
-  AWindow *awin;
-
-  id = wins->initEnum();
-  awin = (AWindow*)wins->getFirstElement( id );
-  while ( awin != NULL ) {
-    awin->XICdestroyed();
-    awin = (AWindow*)wins->getNextElement( id );
-  }
-  wins->closeEnum( id );
-
-  im_style = 0;
-  inputmethod = NULL;
+    for ( wins_cit_t it1 = wins.begin();
+          it1 != wins.end();
+          it1++ ) {
+        (*it1)->XICdestroyed();
+    }
+    
+    im_style = 0;
+    inputmethod = NULL;
 }
 
 #endif
@@ -2128,10 +2099,11 @@ void AGUIX::setTransientWindow( AWindow *twin )
   if ( twin == NULL ) {
     transientwindow = NULL;
   } else {
-    if ( wins->getIndex( twin ) >= 0 ) {
-      // window found
-      transientwindow = twin;
-    }
+      wins_cit_t it1 = std::find( wins.begin(), wins.end(), twin );
+      if ( it1 != wins.end() ) {
+          // window found
+          transientwindow = twin;
+      }
   }
 }
 
@@ -2251,6 +2223,12 @@ int AGUIX::getTextWidth( const char *str, AGUIXFont *font, int len )
 }
 
 int AGUIX::getStrlen4Width( const char *str, int width, int *return_width, AGUIXFont *font )
+{
+    return getStrlen4WidthMaxlen( str, -1, width, return_width, font );
+}
+
+int AGUIX::getStrlen4WidthMaxlen( const char *str, int maxlen,
+                                  int width, int *return_width, AGUIXFont *font )
 {
   int leftlen, leftw, rightlen, rightw, erglen, ergw, midlen, midw;
   AGUIXFont *use_font;
@@ -2270,7 +2248,7 @@ int AGUIX::getStrlen4Width( const char *str, int width, int *return_width, AGUIX
   std::vector<int> lookup_list;
 
   if ( UTF8::getUTF8Mode() != UTF8::UTF8_DISABLED ) {  
-    if ( UTF8::buildCharacterLookupList( str, lookup_list ) != 0 ) {
+    if ( UTF8::buildCharacterLookupListMaxlen( str, maxlen, lookup_list ) != 0 ) {
       if ( return_width != NULL ) *return_width = 0;
       return 0;
     }
@@ -2283,6 +2261,25 @@ int AGUIX::getStrlen4Width( const char *str, int width, int *return_width, AGUIX
 
   leftlen = leftw = 0;
   rightlen = strlen( str );
+  if ( maxlen < rightlen && maxlen >= 0 ) {
+      rightlen = maxlen;
+  }
+  
+  /* check if length is too large, some X libs have problems with too large strings
+     a byte (or character) needs at least 2 pixel so width/2 is a good upper limit
+  */
+
+  if ( UTF8::getUTF8Mode() != UTF8::UTF8_DISABLED ) {
+      int all_characters = lookup_list.size() - 1;
+      if ( all_characters > ( width / 2 ) && width > 0 ) {
+          // rightlen is supposed to be number of bytes
+          rightlen = lookup_list[width / 2];
+      }
+  } else {
+      if ( rightlen > ( width / 2 ) && width > 0 ) {
+          rightlen = width / 2;
+      }
+  }
   rightw = use_font->textWidth( str, rightlen );
 
   if ( leftw >= width ) {
@@ -2295,9 +2292,14 @@ int AGUIX::getStrlen4Width( const char *str, int width, int *return_width, AGUIX
     // from now on leftw is always less than width
     // and rightw always more than width
 
-    // in UTF8 mode len means characters and not bytes!
+    // in UTF8 mode length means characters and not bytes!
     if ( UTF8::getUTF8Mode() != UTF8::UTF8_DISABLED ) {
       rightlen = lookup_list.size() - 1;
+      
+      // check again for pixel limit
+      if ( rightlen > ( width / 2 ) && width > 0 ) {
+          rightlen = width / 2;
+      }
     }
 
     erglen = ergw = 0;
@@ -2556,3 +2558,15 @@ Atom AGUIX::getAtom( atom_name_t name ) const
   }
   return None;
 }
+
+void AGUIX::setColorForName( const std::string &name, int col )
+{
+    _colors_for_widgets[name] = col;
+}
+
+int AGUIX::getColorForName( const std::string &name )
+{
+    if ( _colors_for_widgets.find( name ) == _colors_for_widgets.end() )
+        return -1;
+    return _colors_for_widgets[name];
+}
