@@ -1,6 +1,6 @@
 /* aguix.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2006 Ralf Hoffmann.
+ * Copyright (C) 2001-2007 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: aguix.h,v 1.51 2005/10/13 19:35:47 ralf Exp $ */
 
 #ifndef AGUIX_H
 #define AGUIX_H
@@ -42,6 +41,7 @@
 #endif
 
 #include <map>
+#include <list>
 
 #include "aguixfont.hh"
 
@@ -194,6 +194,14 @@ public:
   int getTextWidth( const char *str, AGUIXFont *font, int len );
   int getStrlen4Width( const char *str, int width, int *return_width, AGUIXFont *font = NULL );
 
+  /**
+   *
+   * @param str
+   * @param maxlen  use not more then len bytes (or <0 for strlen)
+   */
+  int getStrlen4WidthMaxlen( const char *str, int maxlen,
+                             int width, int *return_width, AGUIXFont *font = NULL );
+
   static long timerEvent;
 
   typedef enum { EXTCOLOR_BLACK, EXTCOLOR_DARKGRAY, EXTCOLOR_LIGHTGRAY, EXTCOLOR_WHITE } extcolor_t;
@@ -208,6 +216,9 @@ public:
 
   typedef enum { CLOSE_ATOM, NET_WM_NAME_ATOM, NET_WM_ICON_NAME_ATOM } atom_name_t;
   Atom getAtom( atom_name_t name ) const;
+
+  static void setColorForName( const std::string &name, int col );
+  static int getColorForName( const std::string &name );
 private:
   Display *dsp;
   int scr;
@@ -230,9 +241,18 @@ private:
 #endif
   int colors;
   XEvent LastEvent;
-  List *wins;
-  List *messages;
-  List *fonts;
+  std::list<AWindow*> wins;
+  typedef std::list<AWindow*>::const_iterator wins_cit_t;
+  typedef std::list<AWindow*>::iterator wins_it_t;
+  
+  std::list<AGMessage*> messages;
+  typedef std::list<AGMessage*>::const_iterator agmessage_list_cit_t;
+  typedef std::list<AGMessage*>::iterator agmessage_list_it_t;
+  
+  std::list<AGUIXFont*> fonts;
+  typedef std::list<AGUIXFont*>::const_iterator aguixfont_list_cit_t;
+  typedef std::list<AGUIXFont*>::iterator aguixfont_list_it_t;
+  
   Window groupwin;
   void createGroupWin();
   void destroyGroupWin();
@@ -275,6 +295,8 @@ private:
   std::map<extcolor_t,unsigned long> _extcolors;
   void prepareExtColors( int gray_r, int gray_g, int gray_b );
   void freeExtColors();
+
+  static std::map<std::string,int> _colors_for_widgets;
 };
 
 #endif
