@@ -1,6 +1,6 @@
 /* awindow.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2005 Ralf Hoffmann.
+ * Copyright (C) 2001-2006 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -25,6 +25,7 @@
 #include "button.h"
 #include <list>
 #include <algorithm>
+#include "utf8.hh"
 
 AWindow::AWindow( AGUIX *aguix,
 		  int x,
@@ -55,6 +56,8 @@ AWindow::AWindow( AGUIX *aguix,
   container = NULL;
   contAutoResize = false;
   msgW = msgH = -1;
+
+  _callback_forbidden = false;
 }
 
 AGUIX *AWindow::getAGUIX() const
@@ -336,6 +339,24 @@ bool AWindow::handleMessage(XEvent *E,Message *msg)
     }
   }
 
+  if ( msg->lockElement == NULL &&
+       msg->type == KeyPress &&
+       isTopLevel() == true &&
+       callBackForbidden() == false ) {
+    std::list<key_listener_t>::iterator it;
+    AGMessage *agmsg = AGUIX_allocAGMessage( msg );
+    
+    for ( it = key_listener.begin(); it != key_listener.end(); it++ ) {
+      //TODO pruefen, ob subwin berhautp ein subwin von this is, also recursiv alle childs pruefen
+      if ( ( (*it).mode & KEYCB_WHENVISIBLE ) == 0 || (*it).subwin->isVisible() == true ) {
+        forbidCallBacks();
+        (*it).cb->run( (*it).subwin, *agmsg );
+        permitCallBacks();
+      }
+    }
+    AGUIX_freeAGMessage( agmsg );
+  }
+
   return returnvalue;
 }
 
@@ -617,6 +638,39 @@ int AWindow::addTextFromString( const char *text,
   return 0;
 }
 
+int AWindow::addMultiLineText( const std::string text,
+                               AContainer &ac,
+                               int xpos, int ypos,
+                               AContainer **return_container,
+                               std::list<Text*> *return_text_list )
+{
+  int i;
+  int lines;
+  char **liness;
+  Text *textelement;
+
+  lines = createLines( text.c_str(), &liness );
+
+  AContainer *textac = ac.add( new AContainer( this, 1, lines ), xpos, ypos );
+  textac->setMinSpace( 5 );
+  textac->setMaxSpace( 5 );
+  textac->setBorderWidth( 0 );
+
+  for ( i = 0; i < lines; i++ ) {
+    textelement = (Text*)textac->add( new Text( _aguix, 0, 0, liness[i], 1 ),
+                                      0, i, AContainer::CINCWNR );
+    if ( return_text_list != NULL ) {
+      return_text_list->push_back( textelement );
+    }
+  }
+
+  for ( i = 0; i < lines; i++ ) _freesafe( liness[i] );
+  _freesafe( liness );
+
+  if ( return_container != NULL ) *return_container = textac;
+  return 0;
+}
+
 void AWindow::centerScreen()
 {
   int rw, rh, nx, ny;
@@ -826,6 +880,10 @@ bool AWindow::isTopLevel() const
 
 int AWindow::request( const char *reqtitle, const char *text, const char *buttons, Requester::request_flags_t flags )
 {
+  if ( _parent != NULL ) {
+    return _parent->request( reqtitle, text, buttons, flags );
+  }
+
   if ( req == NULL ) {
     req = new Requester( _aguix, this );
   }
@@ -834,6 +892,10 @@ int AWindow::request( const char *reqtitle, const char *text, const char *button
 
 int AWindow::string_request( const char *reqtitle, const char *lines, const char *default_str, const char *buttons, char **return_str, Requester::request_flags_t flags )
 {
+  if ( _parent != NULL ) {
+    return _parent->string_request( reqtitle, lines, default_str, buttons, return_str, flags );
+  }
+
   if ( req == NULL ) {
     req = new Requester( _aguix, this );
   }
@@ -1055,6 +1117,10 @@ void AWindow::destroy()
 {
   std::list<Widget*>::iterator it1;
 
+  if ( _parent != NULL ) {
+    _parent->removeKeyCallBack( this, NULL );
+  }
+
   if ( _created == true ) {
     for ( it1 = _childs.begin(); it1 != _childs.end(); it1++ ) {
       (*it1)->destroy();
@@ -1078,7 +1144,7 @@ int AWindow::setWMTitle()
 {
   Display *dsp;
   XClassHint classhint;
-  XTextProperty windowname,ticonname;
+  XTextProperty windowname, ticonname, utf8name;
   char *tstr;
   
   dsp = _aguix->getDisplay();
@@ -1093,9 +1159,20 @@ int AWindow::setWMTitle()
   tstr = dupstring( _title.c_str() );
   XStringListToTextProperty( &tstr, 1, &windowname );
   XStringListToTextProperty( &tstr, 1, &ticonname );
-  _freesafe( tstr );
+
   XSetWMName( dsp, win, &windowname );
   XSetWMIconName( dsp, win, &ticonname );
+
+#if defined( X_HAVE_UTF8_STRING ) && !defined( DISABLE_UTF8_SUPPORT )
+  if ( UTF8::getUTF8Mode() != UTF8::UTF8_DISABLED && UTF8::getCurrentEncoding() == UTF8::ENCODING_UTF8 ) {
+    XmbTextListToTextProperty( dsp, &tstr, 1, XUTF8StringStyle, &utf8name );
+    XSetTextProperty( dsp, win, &utf8name, _aguix->getAtom( AGUIX::NET_WM_NAME_ATOM ) );
+    XSetTextProperty( dsp, win, &utf8name, _aguix->getAtom( AGUIX::NET_WM_ICON_NAME_ATOM ) );
+    XFree( utf8name.value );
+  }
+#endif
+
+  _freesafe( tstr );
   XFree( windowname.value );
   XFree( ticonname.value );
   
@@ -1205,3 +1282,85 @@ int AWindow::addWindowEvent( Window subwin, long mask )
   XSelectInput( _aguix->getDisplay(), subwin, curattr.your_event_mask | mask );
   return 0;
 }
+
+int AWindow::getMinWidth() const
+{
+  return minw;
+}
+
+int AWindow::getMinHeight() const
+{
+  return minh;
+}
+
+int AWindow::getMaxWidth() const
+{
+  return maxw;
+}
+
+int AWindow::getMaxHeight() const
+{
+  return maxh;
+}
+
+void AWindow::addKeyCallBack( CallBack *new_cb, int mode )
+{
+  addKeyCallBack( this, new_cb, mode );
+}
+
+void AWindow::addKeyCallBack( AWindow *subwin, CallBack *new_cb, int mode )
+{
+  if ( _parent != NULL ) {
+    _parent->addKeyCallBack( subwin, new_cb, mode );
+  } else {
+    key_listener_t k;
+
+    k.cb = new_cb;
+    k.subwin = subwin;
+    k.mode = mode;
+    key_listener.push_back( k );
+  }
+}
+
+void AWindow::removeKeyCallBack( AWindow *subwin, CallBack *cb )
+{
+  if ( _parent != NULL ) {
+    _parent->removeKeyCallBack( subwin, cb );
+  } else {
+    std::list<key_listener_t>::iterator it;
+    
+    for ( it = key_listener.begin(); it != key_listener.end(); it++ ) {
+      if ( (*it).subwin == subwin )  {
+        if ( cb == NULL || (*it).cb == cb ) {
+          it = key_listener.erase( it );
+        }
+      }
+    }
+  }
+}
+
+void AWindow::removeKeyCallBack( CallBack *cb )
+{
+  if ( cb == NULL ) return;  // removal  of all callbacks are not allowed from public interface
+  
+  removeKeyCallBack( this, cb );
+}
+
+void AWindow::forbidCallBacks()
+{
+  _callback_forbidden = true;
+  if ( _parent != NULL ) _parent->forbidCallBacks();
+}
+
+void AWindow::permitCallBacks()
+{
+  if ( _parent != NULL ) _parent->permitCallBacks();
+  _callback_forbidden = false;
+}
+
+bool AWindow::callBackForbidden() const
+{
+  if ( _callback_forbidden == true ) return true;
+  if ( _parent != NULL ) return _parent->callBackForbidden();
+  return false;
+}
