@@ -3600,3 +3600,75 @@ unsigned int FieldListView::getCurrentMouseButtonState( Window twin )
   _aguix->queryPointer( twin, &mx, &my, &buttons );
   return buttons;
 }
+
+FieldListView::ColorDef::ColorDef()
+{
+  // default colors
+  fg[ 0 ] = 1;
+  fg[ 1 ] = 2;
+  fg[ 2 ] = 1;
+  fg[ 3 ] = 2;
+  bg[ 0 ] = 0;
+  bg[ 1 ] = 1;
+  bg[ 2 ] = 7;
+  bg[ 3 ] = 7;
+}
+
+FieldListView::ColorDef::~ColorDef()
+{
+}
+
+void FieldListView::ColorDef::setFG( colorclass_t cc, int col )
+{
+  if ( cc < 0 || cc > 3 ) return;
+  fg[cc] = col;
+}
+
+int FieldListView::ColorDef::getFG( colorclass_t cc ) const
+{
+  if ( cc < 0 || cc > 3 ) return 0;
+  return fg[cc];
+}
+
+void FieldListView::ColorDef::setBG( colorclass_t cc, int col )
+{
+  if ( cc < 0 || cc > 3 ) return;
+  bg[cc] = col;
+}
+
+int FieldListView::ColorDef::getBG( colorclass_t cc ) const
+{
+  if ( cc < 0 || cc > 3 ) return 0;
+  return bg[cc];
+}
+
+void FieldListView::setColor( int row, const ColorDef &col )
+{
+  if ( ( row < 0 ) || ( row >= elements ) ) return;
+  
+  elementarray[ row ]->setFG( CC_NORMAL, col.getFG( CC_NORMAL ) );
+  elementarray[ row ]->setFG( CC_ACTIVE, col.getFG( CC_ACTIVE ) );
+  elementarray[ row ]->setFG( CC_SELECT, col.getFG( CC_SELECT ) );
+  elementarray[ row ]->setFG( CC_SELACT, col.getFG( CC_SELACT ) );
+  elementarray[ row ]->setBG( CC_NORMAL, col.getBG( CC_NORMAL ) );
+  elementarray[ row ]->setBG( CC_ACTIVE, col.getBG( CC_ACTIVE ) );
+  elementarray[ row ]->setBG( CC_SELECT, col.getBG( CC_SELECT ) );
+  elementarray[ row ]->setBG( CC_SELACT, col.getBG( CC_SELACT ) );
+}
+
+FieldListView::ColorDef FieldListView::getColor( int row ) const
+{
+  ColorDef col;
+  
+  if ( ( row < 0 ) || ( row >= elements ) ) return col;
+  
+  col.setFG( CC_NORMAL, elementarray[ row ]->getFG( CC_NORMAL ) );
+  col.setFG( CC_ACTIVE, elementarray[ row ]->getFG( CC_ACTIVE ) );
+  col.setFG( CC_SELECT, elementarray[ row ]->getFG( CC_SELECT ) );
+  col.setFG( CC_SELACT, elementarray[ row ]->getFG( CC_SELACT ) );
+  col.setBG( CC_NORMAL, elementarray[ row ]->getBG( CC_NORMAL ) );
+  col.setBG( CC_ACTIVE, elementarray[ row ]->getBG( CC_ACTIVE ) );
+  col.setBG( CC_SELECT, elementarray[ row ]->getBG( CC_SELECT ) );
+  col.setBG( CC_SELACT, elementarray[ row ]->getBG( CC_SELACT ) );
+  return col;
+}
