@@ -164,6 +164,22 @@ public:
 
   typedef enum { MOUSE_SELECT_NORMAL, MOUSE_SELECT_ALT } mouse_select_t;
   static int changeSelectMode( mouse_select_t nm );
+  
+  class ColorDef
+  {
+  public:
+    ColorDef();
+    ~ColorDef();
+
+    void setFG( colorclass_t cc, int col );
+    int getFG( colorclass_t cc ) const;
+    void setBG( colorclass_t cc, int col );
+    int getBG( colorclass_t cc ) const;
+  private:
+    int fg[4], bg[4];
+  };
+  void setColor( int row, const ColorDef &col );
+  ColorDef getColor( int row ) const;
 protected:
   int fields;
   int *fieldwidth;
