@@ -1,6 +1,6 @@
 /* fieldlistviewdnd.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2002-2006 Ralf Hoffmann.
+ * Copyright (C) 2002-2007 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -28,7 +28,6 @@ const char *FieldListViewDND::type="FieldListViewDND";
 FieldListViewDND::~FieldListViewDND()
 {
   removealldndtexts();
-  delete dndtexts;
 }
 
 FieldListViewDND::FieldListViewDND( AGUIX *taguix,
@@ -43,7 +42,6 @@ FieldListViewDND::FieldListViewDND( AGUIX *taguix,
 								 height,
 								 tdata )
 {
-  dndtexts = new ArrayList();
   dndMode = DND_IDLE;
   dndtext = NULL;
 }
@@ -91,10 +89,11 @@ void FieldListViewDND::handleSelect(Message *msg)
 	    else
 	      ti = CC_NORMAL;
 	  }
-	  
-	  char *tstr = (char*)dndtexts->getElementAt( clickLastSelectedRow );
-	  if ( tstr == NULL ) tstr = dupstring( ( elementarray[ clickLastSelectedRow ]->getText( 0 ) ).c_str() );
-	  else tstr = dupstring( tstr );
+
+          const char *tstr = NULL;
+          if ( clickLastSelectedRow >= 0 && clickLastSelectedRow < (int)dndtexts.size() )
+              tstr = dndtexts[clickLastSelectedRow].c_str();
+	  if ( tstr == NULL ) tstr = ( elementarray[ clickLastSelectedRow ]->getText( 0 ) ).c_str();
 
 	  agmsg = AGUIX_allocAGMessage();
 	  agmsg->dnd.element = this;
@@ -119,7 +118,6 @@ void FieldListViewDND::handleSelect(Message *msg)
 				 getBG( clickLastSelectedRow, ti),
 				 font );
 	  dndtext->create();
-	  _freesafe( tstr );
 	}
       }
       return;
@@ -221,52 +219,29 @@ bool FieldListViewDND::isType(const char *qtype) const
 
 void FieldListViewDND::removealldndtexts()
 {
-  int id=dndtexts->initEnum();
-  char *tstr=(char*)dndtexts->getFirstElement(id);
-  while(tstr!=NULL) {
-    _freesafe(tstr);
-    dndtexts->removeFirstElement();
-    tstr=(char*)dndtexts->getFirstElement(id);
-  }
-  dndtexts->closeEnum(id);
+    dndtexts.clear();
 }
 
-void FieldListViewDND::removedndtextat(int index2)
+void FieldListViewDND::replacedndtext( int index2, const char *tstr )
 {
-  char *tstr=(char*)dndtexts->getElementAt(index2);
-  dndtexts->removeElementAt(index2);
-  if(tstr!=NULL) _freesafe(tstr);
+    if ( index2 < 0 || index2 >= (int)dndtexts.size() ) return;
+    dndtexts[index2] = tstr;
 }
 
-void FieldListViewDND::replacedndtext(int index2,char *tstr)
+void FieldListViewDND::adddndtext( const char *tstr )
 {
-  if((index2<0)||(index2>=dndtexts->size())) return;
-  char *tstr2=(char*)dndtexts->exchangeElement(index2,dupstring(tstr));
-  if(tstr2!=NULL) _freesafe(tstr2);
-}
-
-void FieldListViewDND::insertdndtext(int index2,char *tstr)
-{
-  dndtexts->addElementAt(index2,dupstring(tstr));
-}
-
-void FieldListViewDND::adddndtext(char *tstr)
-{
-  dndtexts->addElement(dupstring(tstr));
+    dndtexts.push_back( tstr );
 }
 
 void FieldListViewDND::setSizeDNDText(int ns)
 {
-  int elems=dndtexts->size();
-  char *tstr;
-  while(elems<ns) {
-    dndtexts->addElement(NULL);
-    elems++;
-  }
-  while(elems>ns) {
-    tstr=(char*)dndtexts->getElementAt(elems-1);
-    dndtexts->removeElementAt(elems-1);
-    elems--;
-    if(tstr!=NULL) _freesafe(tstr);
-  }
+    int elems = (int)dndtexts.size();
+    while ( elems < ns ) {
+        dndtexts.push_back( "" );
+        elems++;
+    }
+    while ( elems > ns ) {
+        dndtexts.pop_back();
+        elems--;
+    }
 }
