@@ -1,6 +1,6 @@
 /* lowlevelfunc.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2005 Ralf Hoffmann.
+ * Copyright (C) 2001-2006 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,11 +18,11 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: lowlevelfunc.cc,v 1.34 2005/10/16 20:12:29 ralf Exp $ */
 
 #include "lowlevelfunc.h"
 #include <locale.h>
 #include <algorithm>
+#include "utf8.hh"
 
 #ifdef USE_MEM_SYSTEM
 typedef struct _safemem {void *ptr;
@@ -33,10 +33,8 @@ unsigned long maxmemusage,memusage;
 short memsystem_inited = 0;
 void _memsysteminit();
 
-#ifdef WANT_THREADS
 #include "mutex.h"
 MutEx memlock;
-#endif
 
 #endif
 
@@ -53,9 +51,7 @@ void *_allocsafe(size_t size)
     exit(1);
   }
 #ifdef USE_MEM_SYSTEM
-#ifdef WANT_THREADS
   memlock.lock();
-#endif
   if ( memsystem_inited != 1 ) _memsysteminit();
   tsmptr=(SafeMem*)malloc(sizeof(SafeMem));
   tsmptr->ptr=ptr;
@@ -64,9 +60,7 @@ void *_allocsafe(size_t size)
   firstmemstr=tsmptr;
   memusage+=size;
   if(memusage>maxmemusage) maxmemusage=memusage;
-#ifdef WANT_THREADS
   memlock.unlock();
-#endif
 #endif
   return ptr;
 }
@@ -100,9 +94,7 @@ void _freesafe(void *p)
 {
   SafeMem *tsmptr,*found,*prefound;
 
-#ifdef WANT_THREADS
   memlock.lock();
-#endif
   if ( memsystem_inited != 1 ) _memsysteminit();
   tsmptr=firstmemstr;
   found=NULL;
@@ -127,9 +119,7 @@ void _freesafe(void *p)
   } else {
     fprintf( stderr, "Freigabe eines unauthorisierten Speichers!\n");
   }
-#ifdef WANT_THREADS
   memlock.unlock();
-#endif
   free(p);
 }
 
@@ -139,9 +129,7 @@ void _memsystemcheck()
   int nr;
 
   if ( memsystem_inited != 1 ) return;
-#ifdef WANT_THREADS
   memlock.lock();
-#endif
   tsmptr=firstmemstr;
   nr=0;
   while(tsmptr!=NULL) {
@@ -159,9 +147,7 @@ void _memsystemcheck()
     printf("Es gibt noch %d nicht freigelassene Speicherstcke!\n",nr);
   }
 #endif
-#ifdef WANT_THREADS
   memlock.unlock();
-#endif
 }
 
 void _memsysteminit()
@@ -185,23 +171,23 @@ char *dupstring(const char *str)
 
 int MakeLong2NiceStr( loff_t size, std::string &buffer, bool do_nice )
 {
-  static char own_thousands_sep = '\0';
+  static std::string own_thousands_sep;
   struct lconv *current_locale;
   std::string numstr;
   loff_t tmpval = size;
   int digit, i;
 
-  if ( own_thousands_sep == '\0' ) {
+  if ( own_thousands_sep.length() < 1 ) {
     // thousands separator isn't set so try to determine it
     current_locale = localeconv();
     /* check if the locale defines thousands_sep */
     if ( ( current_locale->thousands_sep != NULL ) &&
 	 ( *( current_locale->thousands_sep ) != 0 ) ) {
-      /* yes, it does. just copy the char. */
-      own_thousands_sep = *( current_locale->thousands_sep );
+      /* yes, it does so store the string */
+      own_thousands_sep = current_locale->thousands_sep;
     } else {
       // default is the dot
-      own_thousands_sep = '.';
+      own_thousands_sep = ".";
     }
   }
 
@@ -241,13 +227,17 @@ char *shrinkstring( const char *str, int maxlen, AWidth &lencalc )
   char *newstr;
   const char *hitstr, *trystr;
   std::string str1;
+  size_t charlen;
+  int pos;
 
   width = lencalc.getWidth( str );
 
   if ( width <= maxlen ) return dupstring( str );
 
   ddd_width = lencalc.getWidth( "..." );
-  lwidth = lencalc.getWidth( str, 1 );
+
+  charlen = UTF8::getLenOfCharacter( str );
+  lwidth = lencalc.getWidth( str, charlen );
 
   if ( ( lwidth + ddd_width ) <= maxlen) {
     rest_width = maxlen - ddd_width;
@@ -261,12 +251,16 @@ char *shrinkstring( const char *str, int maxlen, AWidth &lencalc )
 
     // now find remaining character from right end
     hitstr = NULL;
-    trystr = str + strlen( str ) - 1;
+
+    pos = strlen( str );
+    UTF8::movePosToPrevChar( str, pos );
+    trystr = str + pos;
     while ( trystr >= str ) {
       rwidth = lencalc.getWidth( trystr );
       if ( rwidth <= rest_width ) hitstr = trystr;
       else break;
-      trystr--;
+      UTF8::movePosToPrevChar( str, pos );
+      trystr = str + pos;
     }
     
     if ( hitstr != NULL ) {
