@@ -41,21 +41,14 @@ char *catstring(const char *str1,const char *str2);
 char *shrinkstring( const char *str, int maxlen, AWidth &lencalc );
 int MakeLong2NiceStr( loff_t size, std::string &buffer, bool do_nice = true );
 
-// this is the number of bytes need for a "nice" number with dots after 3 digits
-// it's the number of bytes for the type plus all dots plus 1 for the trailing zero
-// Because this define shouldn't do any runtime calculation I use this
-// approx.: 1 dot for every byte. You cannot fill 3 digits with one byte so
-// it's more then really needed
-#define A_BYTESFORNICENUMBER(x) ( A_BYTESFORNUMBER(x) + sizeof(x) + 1 )
-
 double diffgtod( struct timeval *tv1, struct timeval *tv0 );
 long ldiffgtod( struct timeval *tv1, struct timeval *tv0 );
 long ldiffgtod_m( const struct timeval *tv1, const struct timeval *tv0 );
 
 #ifdef DEVELOPER
-  #define debugmsg(P) printf(P)
+# define debugmsg(P) printf( "[AGUIX]: %s\n", P )
 #else
-  #define debugmsg(P) 
+# define debugmsg(P) 
 #endif
 
 int AGUIX_getQuoteMode( const char *str );
