@@ -1,6 +1,6 @@
 /* slider.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2005-2006 Ralf Hoffmann.
+ * Copyright (C) 2005-2007 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -60,6 +60,8 @@ Slider::Slider( AGUIX *caguix, int cx, int cy, int cwidth, int cheight, bool cve
   
   _init_timer_wait = 0;
   _allow_timerevent_break = true;
+
+  m_bg = -1;
 }
 
 Slider::~Slider()
@@ -157,6 +159,7 @@ void Slider::redraw()
   struct point p[3];
   XPoint arrow1[3], arrow2[3];
   int bw, bgbw;
+  int bg_to_use;
 
   bgbw = 1;
 
@@ -167,7 +170,12 @@ void Slider::redraw()
 
   bw = 2;
 
-  _aguix->SetWindowBG( win, _parent->getBG() );
+  if ( m_bg < 0 ) {
+      bg_to_use = _parent->getBG();
+  } else {
+      bg_to_use = m_bg;
+  }
+  _aguix->SetWindowBG( win, bg_to_use );
   _aguix->ClearWin( win );
 
   // draw background
@@ -309,7 +317,7 @@ void Slider::redraw()
     }
   }
 
-  _aguix->setFG( _parent->getBG() );
+  _aguix->setFG( bg_to_use );
   _aguix->FillRectangle( win, tx, ty,
 			 tw, th );
 
@@ -650,3 +658,18 @@ void Slider::enableTimer()
   _aguix->enableTimer();
   _init_timer_wait = 3;
 }
+
+int Slider::getBG() const
+{
+    return m_bg;
+}
+
+void Slider::setBG( int v )
+{
+    m_bg = v;
+    
+    if ( m_bg < 0 )
+        m_bg = -1;
+
+    redraw();
+}
