@@ -1,6 +1,6 @@
 /* slider.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2005 Ralf Hoffmann.
+ * Copyright (C) 2005-2007 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -60,6 +60,9 @@ public:
   
   void setDisplayFocus( bool nv );
   bool getDisplayFocus() const;
+
+  int getBG() const;
+  void setBG( int v );
 protected:
   static const char *type;
   
@@ -82,6 +85,8 @@ protected:
 
   void enableTimer();
   int _init_timer_wait;
+
+  int m_bg;
 };
 
 #endif
