@@ -23,6 +23,7 @@
 #include "text.h"
 #include "lowlevelfunc.h"
 #include "awindow.h"
+#include "drawablecont.hh"
 
 const char *Text::type="Text";
 
@@ -90,10 +91,7 @@ void Text::setColor(int tcolor)
 
 void Text::redraw()
 {
-  GC usegc;
   if ( isCreated() == true ) {
-    if(font==NULL) usegc=0;
-    else usegc=font->getGC();
     if ( bgset == false ) {
       if ( ownbg == true ) {
 	_aguix->SetWindowBG( win, bg );
@@ -103,9 +101,9 @@ void Text::redraw()
       bgset = true;
     }
     _aguix->ClearWin(win);
-    _aguix->setFG(usegc,color);
-    if(font==NULL) _aguix->DrawText(win,text,0,0);
-    else _aguix->DrawText(win,font,text,0,0);
+
+    DrawableCont dc( _aguix, win );
+    _aguix->DrawText( dc, font, text, 0, 0, color );
   }
 }
 
