@@ -1,6 +1,6 @@
 /* basic_actions.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2004 Ralf Hoffmann.
+ * Copyright (C) 2001-2007 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,13 +18,13 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: basic_actions.cc,v 1.27 2005/12/04 20:00:38 ralf Exp $ */
 
 #include "basic_actions.h"
 #include "listermode.h"
 #include "normalmode.h"
 #include "worker.h"
 #include "wcfiletype.hh"
+#include "fileentry.hh"
 
 /***********
   DNDAction
@@ -1076,13 +1076,13 @@ int ChangeHiddenFlag::run( WPUContext *wpu, ActionMessage *msg )
           nm1=(NormalMode*)lm1;
           switch(mode) {
             case 1:
-              nm1->setShowHiddenE(false);
+              nm1->setShowHidden(false);
               break;
             case 2:
-              nm1->setShowHiddenE(true);
+              nm1->setShowHidden(true);
               break;
             default:
-              nm1->toggleHiddenE();          
+              nm1->toggleHidden();          
           }
         }
       }
