@@ -1,6 +1,6 @@
 /* compregex.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2004 Ralf Hoffmann.
+ * Copyright (C) 2004,2006 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: compregex.cc,v 1.2 2004/10/27 21:06:16 ralf Exp $ */
 
 #include "compregex.h"
 #include <aguix/lowlevelfunc.h>
@@ -41,56 +40,81 @@ CompRegEx::~CompRegEx()
 
 void CompRegEx::freeCompiled()
 {
-  while ( compiled.size() > 0 ) {
-    freeLast();
+  while ( _compiled.size() > 0 ) {
+    freeLast( false );
   }
-  compiled.clear();
+  while ( _compiled_nocase.size() > 0 ) {
+    freeLast( true );
+  }
+  _compiled.clear();
+  _compiled_nocase.clear();
 }
 
-const struct CompRegEx::regExpComp_t &CompRegEx::getCompiled( const char *pattern )
+const struct CompRegEx::regExpComp_t &CompRegEx::getCompiled( const char *pattern, bool ignore_case )
 {
   int erg;
   regExpComp_t *newre, **pe1;
   
   if ( pattern == NULL ) throw 1;
 
-  pe1 = compiled.findToFront( pattern );
+  if ( ignore_case == true ) {
+    pe1 = _compiled_nocase.findToFront( pattern );
+  } else {
+    pe1 = _compiled.findToFront( pattern );
+  }
   if ( pe1 != NULL ) {
     return **pe1;
   }
 
   newre = new regExpComp_t;
-  erg = regcomp( &(newre->patternReg), pattern, REG_NOSUB );
+  erg = regcomp( &(newre->patternReg), pattern, REG_NOSUB | ( ( ignore_case == true ) ? REG_ICASE : 0 ) );
   if ( erg != 0 ) {
     // error
+    delete newre;
     throw 2;
   }
   newre->pattern = dupstring( pattern );
   
-  if ( compiled.size() >= maxsize ) {
-    freeLast();
+  if ( ignore_case == true ) {
+    if ( _compiled_nocase.size() >= maxsize ) {
+      freeLast( true );
+    }
+    _compiled_nocase.insert( pattern, newre );
+  } else {
+    if ( _compiled.size() >= maxsize ) {
+      freeLast( false );
+    }
+    _compiled.insert( pattern, newre );
   }
-  compiled.insert( pattern, newre );
   return *newre;
 }
 
-void CompRegEx::freeLast()
+void CompRegEx::freeLast( bool nocase )
 {
   regExpComp_t **pe1, *e1;
 
-  pe1 = compiled.getLast();
+  if ( nocase == true ) {
+    pe1 = _compiled_nocase.getLast();
+  } else {
+    pe1 = _compiled.getLast();
+  }
   if ( pe1 != NULL ) {
     e1 = *pe1;
     regfree( &(e1->patternReg) );
     _freesafe( e1->pattern );
     delete e1;
-    compiled.removeLast();
+
+    if ( nocase == true ) {
+      _compiled_nocase.removeLast();
+    } else {
+      _compiled.removeLast();
+    }
   }
 }
 
 #endif
 
-bool CompRegEx::match( const char *pattern, const char *str )
+bool CompRegEx::match( const char *pattern, const char *str, bool ignore_case )
 {
   bool matched = false;
 #ifdef HAVE_REGEX
@@ -104,7 +128,7 @@ bool CompRegEx::match( const char *pattern, const char *str )
   
 #ifdef HAVE_REGEX
   try {
-    const struct regExpComp_t &x = getCompiled( pattern );
+    const struct regExpComp_t &x = getCompiled( pattern, ignore_case );
     erg = regexec( &(x.patternReg), str, 0, NULL, 0 );
     if ( erg == 0 ) matched = true;
   } catch( int err ) {
@@ -114,4 +138,3 @@ bool CompRegEx::match( const char *pattern, const char *str )
 #endif
   return matched;
 }
-
