@@ -1,7 +1,7 @@
-/* A Bison parser, made from configparser.y, by GNU bison 1.75.  */
+/* A Bison parser, made by GNU Bison 2.1.  */
 
 /* Skeleton parser for Yacc-like parsing with Bison,
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -15,17 +15,14 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.  */
 
 /* As a special exception, when this file is copied by Bison into a
    Bison output file, you may use that output file without restriction.
    This special exception was added by the Free Software Foundation
    in version 1.24 of Bison.  */
 
-#ifndef BISON_CONFIGPARSER_TAB_H
-# define BISON_CONFIGPARSER_TAB_H
-
 /* Tokens.  */
 #ifndef YYTOKENTYPE
 # define YYTOKENTYPE
@@ -319,18 +316,23 @@
      SEARCHOP_WCP = 542,
      EDITCOMMAND_WCP = 543,
      SHOWPREVRESULTS_WCP = 544,
-     ERROR = 545,
-     ACTIVESIDE_WCP = 546,
-     SHOWFREESPACE_WCP = 547,
-     ACTIVEMODE_WCP = 548,
-     ASK_WCP = 549,
-     SSHALLOW_WCP = 550,
-     FIELD_WIDTH_WCP = 551,
-     QUICKSEARCHENABLED_WCP = 552,
-     STRING_WCP = 553,
-     NUM_WCP = 554
+     TEXTVIEW_WCP = 545,
+     TEXTVIEWHIGHLIGHTED_WCP = 546,
+     DIRBOOKMARKOP_WCP = 547,
+     ERROR = 548,
+     ACTIVESIDE_WCP = 549,
+     SHOWFREESPACE_WCP = 550,
+     ACTIVEMODE_WCP = 551,
+     ASK_WCP = 552,
+     SSHALLOW_WCP = 553,
+     FIELD_WIDTH_WCP = 554,
+     QUICKSEARCHENABLED_WCP = 555,
+     FILTEREDSEARCHENABLED_WCP = 556,
+     STRING_WCP = 557,
+     NUM_WCP = 558
    };
 #endif
+/* Tokens.  */
 #define LEFTBRACE_WCP 258
 #define RIGHTBRACE_WCP 259
 #define GLOBAL_WCP 260
@@ -618,33 +620,38 @@
 #define SEARCHOP_WCP 542
 #define EDITCOMMAND_WCP 543
 #define SHOWPREVRESULTS_WCP 544
-#define ERROR 545
-#define ACTIVESIDE_WCP 546
-#define SHOWFREESPACE_WCP 547
-#define ACTIVEMODE_WCP 548
-#define ASK_WCP 549
-#define SSHALLOW_WCP 550
-#define FIELD_WIDTH_WCP 551
-#define QUICKSEARCHENABLED_WCP 552
-#define STRING_WCP 553
-#define NUM_WCP 554
+#define TEXTVIEW_WCP 545
+#define TEXTVIEWHIGHLIGHTED_WCP 546
+#define DIRBOOKMARKOP_WCP 547
+#define ERROR 548
+#define ACTIVESIDE_WCP 549
+#define SHOWFREESPACE_WCP 550
+#define ACTIVEMODE_WCP 551
+#define ASK_WCP 552
+#define SSHALLOW_WCP 553
+#define FIELD_WIDTH_WCP 554
+#define QUICKSEARCHENABLED_WCP 555
+#define FILTEREDSEARCHENABLED_WCP 556
+#define STRING_WCP 557
+#define NUM_WCP 558
 
 
 
 
-#ifndef YYSTYPE
+#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
 #line 196 "configparser.y"
-typedef union {
+typedef union YYSTYPE {
   int num;
   char *strptr;
-} yystype;
-/* Line 1281 of /usr/share/bison/yacc.c.  */
-#line 643 "configparser.tab.h"
-# define YYSTYPE yystype
+} YYSTYPE;
+/* Line 1447 of yacc.c.  */
+#line 649 "configparser.tab.h"
+# define yystype YYSTYPE /* obsolescent; will be withdrawn */
+# define YYSTYPE_IS_DECLARED 1
+# define YYSTYPE_IS_TRIVIAL 1
 #endif
 
 extern YYSTYPE yylval;
 
 
-#endif /* not BISON_CONFIGPARSER_TAB_H */
 
