@@ -1,6 +1,6 @@
 /* configtokens.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2003-2005 Ralf Hoffmann.
+ * Copyright (C) 2003-2007 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -21,7 +21,7 @@
 /* $Id: configtokens.cc,v 1.24 2005/12/11 19:25:53 ralf Exp $ */
 
 #include "wdefines.h"
-#include <aguix/util.h>
+#include "simplelist.hh"
 #include "configtokens.h"
 #include "configparser.tab.h"
 
@@ -317,7 +317,11 @@ struct mytoken tokenlist[]={
   { ALTERNATIVE_WCP, "alternative" },
   { SEARCHOP_WCP, "searchop" },
   { EDITCOMMAND_WCP, "editcommand" },
-  { SHOWPREVRESULTS_WCP, "showprevresults" }
+  { SHOWPREVRESULTS_WCP, "showprevresults" },
+  { TEXTVIEW_WCP, "textview" },
+  { TEXTVIEWHIGHLIGHTED_WCP, "textviewhighlighted" },
+  { FILTEREDSEARCHENABLED_WCP, "filteredsearchenabled"},
+  { DIRBOOKMARKOP_WCP, "dirbookmarkop" }
 };
 
 ArrayList *tokenlist_sorted = NULL;
