@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: createsymlinkop.h,v 1.10 2004/10/27 21:06:45 ralf Exp $ */
+/* $Id: createsymlinkop.h,v 1.11 2005/10/19 18:06:34 ralf Exp $ */
 
 #ifndef CREATESYMLINKOP_H
 #define CREATESYMLINKOP_H
@@ -46,7 +46,7 @@ public:
 #if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
   using FunctionProto::run;
 #endif
-  virtual int run(ActionMessage*);
+  int run( WPUContext *wpu, ActionMessage* );
   virtual bool save(Datei*);
   virtual const char *getDescription();
   virtual int configure();
@@ -67,7 +67,7 @@ protected:
   
   bool tsame_dir,tlocal,trequestflags;
   
-  int normalmodecreatesl();
+  int normalmodecreatesl( ActionMessage* );
 };
 
 #endif
