@@ -1,6 +1,6 @@
 /* cursorops.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2006 Ralf Hoffmann.
+ * Copyright (C) 2001-2007 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: cursorops.cc,v 1.25 2006/02/09 07:01:43 ralf Exp $ */
 
 #include "cursorops.h"
 #include "listermode.h"
@@ -26,6 +25,7 @@
 #include "worker.h"
 #include "wpucontext.h"
 #include "ownop.h"
+#include "fileentry.hh"
 
 /******
  RowUp
@@ -648,7 +648,12 @@ int ParentDirOp::run( WPUContext *wpu, ActionMessage *msg )
       if(lm1!=NULL) {
         if(lm1->isType("NormalMode")==true) {
           nm1=(NormalMode*)lm1;
-          nm1->parent();
+
+          if ( nm1->filteredSearchActive() == true ) {
+              nm1->deactivateFilteredSearch();
+          } else {
+              nm1->parent();
+          }
         }
       }
     }
