@@ -1,6 +1,6 @@
 /* filereq.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2004 Ralf Hoffmann.
+ * Copyright (C) 2001-2007 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: filereq.cc,v 1.21 2005/12/12 19:59:57 ralf Exp $ */
 
 #include "filereq.h"
 #include "worker_locale.h"
@@ -142,9 +141,16 @@ int FileRequester::request( const char *title,
               if ( msg->fieldlv.row == lastrow ) {
                 // eventl. Doppelklick
                 if ( aguix->isDoubleClick( msg->fieldlv.time, lasttime ) == true ) {
-                  ArrayList *files = verz->getFiles();
-                  FileEntry *fe = (FileEntry*)files->getElementAt( lastrow );
-                  if ( fe != NULL ) {
+                  
+                  int p = lastrow;
+                  Verzeichnis::verz_it fe_it1;
+
+                  for ( fe_it1 = verz->begin();
+                        fe_it1 != verz->end() && p > 0;
+                        fe_it1++, p-- );
+
+                  if ( fe_it1 != verz->end() ) {
+                    FileEntry *fe = *fe_it1;
                     if ( fe->isDir() == true ) {
                       char *tstr = (char*)_allocsafe( strlen( actdir ) + 1 + strlen( fe->name ) + 2 );
                       sprintf( tstr, "%s/%s", actdir, fe->name );
@@ -182,29 +188,38 @@ int FileRequester::request( const char *title,
   if(endmode==1) {
     // Ok
     selfes=new List();
-    ArrayList *files=verz->getFiles();
-    FileEntry *fe=(FileEntry*)files->getElementAt(1);
-    int row = 1;
-    while ( fe != NULL ) {
-      if ( lv->getSelect( row ) == true ) {
-        selfes->addElement( fe->duplicate() );
-      }
-      fe = (FileEntry*)files->getNextElement();
-      row++;
+
+    Verzeichnis::verz_it fe_it1 = verz->begin();
+    if ( fe_it1 != verz->end() ) {
+        fe_it1++;
+        int row = 1;
+
+        while ( fe_it1 != verz->end() ) {
+            if ( lv->getSelect( row ) == true ) {
+                selfes->addElement( (*fe_it1)->duplicate() );
+            }
+            fe_it1++;
+            row++;
+        }
     }
   } else if(endmode==2) {
     selfes=new List();
-    ArrayList *files=verz->getFiles();
-    FileEntry *fe=(FileEntry*)files->getElementAt(1);
-    int row = 1;
-    while ( fe != NULL ) {
-      if ( row == lastrow ) {
-        selfes->addElement( fe->duplicate() );
-        break;
-      }
-      fe = (FileEntry*)files->getNextElement();
-      row++;
+
+    Verzeichnis::verz_it fe_it1 = verz->begin();
+    if ( fe_it1 != verz->end() ) {
+        fe_it1++;
+        int row = 1;
+
+        while ( fe_it1 != verz->end() ) {
+            if ( row == lastrow ) {
+                selfes->addElement( (*fe_it1)->duplicate() );
+                break;
+            }
+            fe_it1++;
+            row++;
+        }
     }
+    
     endmode=1;
   }
   delete win;
@@ -251,10 +266,13 @@ void FileRequester::setDir(const char *dir)
   actdir=tstr;
   sg->setText(actdir);
   verz->sort(0);
-  ArrayList *files=verz->getFiles();
-  FileEntry *fe=(FileEntry*)files->getFirstElement();
+
   lv->setSize( 0 );
-  while(fe!=NULL) {
+  
+  for ( Verzeichnis::verz_it fe_it1 = verz->begin();
+        fe_it1 != verz->end();
+        fe_it1++ ) {
+    FileEntry *fe = *fe_it1;
     row = lv->addRow();
     lv->setText( row, 0, fe->name );
     if(fe->isDir()==false) {
@@ -269,7 +287,6 @@ void FileRequester::setDir(const char *dir)
       lv->setBG( row, FieldListView::CC_ACTIVE, 0 );
       lv->setBG( row, FieldListView::CC_SELACT, 3 );
     }
-    fe=(FileEntry*)files->getNextElement();
   }
   lv->redraw();
 }
@@ -455,9 +472,17 @@ int FileRequester::request_entry( const char *title,
               if ( msg->fieldlv.row == lastrow ) {
                 // eventl. Doppelklick
                 if ( aguix->isDoubleClick( msg->fieldlv.time, lasttime ) == true ) {
-                  ArrayList *files = verz->getFiles();
-                  FileEntry *fe = (FileEntry*)files->getElementAt( lastrow );
-                  if ( fe != NULL ) {
+                  
+                  int p = lastrow;
+                  Verzeichnis::verz_it fe_it1;
+
+                  for ( fe_it1 = verz->begin();
+                        fe_it1 != verz->end() && p > 0;
+                        fe_it1++, p-- );
+
+                  if ( fe_it1 != verz->end() ) {
+                    FileEntry *fe = *fe_it1;
+
                     if ( fe->isDir() == true ) {
                       char *tstr = (char*)_allocsafe( strlen( actdir ) + 1 + strlen( fe->name ) + 2 );
                       sprintf( tstr, "%s/%s", actdir, fe->name );
@@ -578,10 +603,13 @@ void FileRequester::setDirOneSelect( const char *dir )
   actdir=tstr;
   sg->setText(actdir);
   verz->sort(0);
-  ArrayList *files=verz->getFiles();
-  FileEntry *fe=(FileEntry*)files->getFirstElement();
+
   lv->setSize( 0 );
-  while(fe!=NULL) {
+  
+  for ( Verzeichnis::verz_it fe_it1 = verz->begin();
+        fe_it1 != verz->end();
+        fe_it1++ ) {
+    FileEntry *fe = *fe_it1;
     row = lv->addRow();
     lv->setText( row, 0, fe->name );
     if(fe->isDir()==false) {
@@ -598,7 +626,6 @@ void FileRequester::setDirOneSelect( const char *dir )
       lv->setBG( row, FieldListView::CC_SELACT, 3 );
       lv->setData( row, 1 );
     }
-    fe=(FileEntry*)files->getNextElement();
   }
   lv->redraw();
 }
