@@ -304,8 +304,8 @@ void Lister::configure()
               modes[j]->configure();
             } else {
               for(i=0;i<nr;i++) {
-                if(i!=j) cbs[i]->setState(0);
-                else cbs[i]->setState((cbs[i]->getState()==0)?1:0);
+                if ( i != j ) cbs[i]->setState( false );
+                else cbs[i]->setState( ( cbs[i]->getState() == false ) ? true : false );
               }
             }
           }
@@ -314,7 +314,7 @@ void Lister::configure()
         for(j=0;j<nr;j++) if(cbs[j]==msg->choose.button) break;
         if(j<nr) {
           for(i=0;i<nr;i++) {
-            if(i!=j) cbs[i]->setState(0);
+            if ( i != j ) cbs[i]->setState( false );
           }
         }
       }
@@ -327,7 +327,7 @@ void Lister::configure()
     //       diese bearbeiten
     j=-1;
     for(i=0;i<nr;i++) {
-      if(cbs[i]->getState()==1) {
+      if ( cbs[i]->getState() == true ) {
         j=i;
         break;
       }
@@ -357,7 +357,7 @@ int Lister::saveState(Datei *fh)
   if ( fh == NULL ) return 1;
   
   if ( activemode != NULL ) {
-    WConfig::configPutPairString( fh, "activemode", Worker::getNameOfMode( Worker::getID4Mode( activemode ) ) );
+    fh->configPutPairString( "activemode", Worker::getNameOfMode( Worker::getID4Mode( activemode ) ) );
   }
   // Ueber alle Modes: ID speichern und dann den Mode speichern ueberlassen
   j = parent->getMaxModeNr();
@@ -366,9 +366,9 @@ int Lister::saveState(Datei *fh)
     str1 = "\"";
     str1 += Worker::getNameOfMode( Worker::getID4Mode( modes[i] ) );
     str1 += "\"";
-    WConfig::configOpenSection( fh, str1.c_str() );
+    fh->configOpenSection( str1.c_str() );
     modes[i]->save( fh );
-    WConfig::configCloseSection( fh );
+    fh->configCloseSection();
   }
   return 0;
 }
