@@ -35,8 +35,10 @@ class Worker;
 class AGUIX;
 class ListerMode;
 
-typedef enum {CYCLICFUNC_MODE_NORMAL,CYCLICFUNC_MODE_FIRSTNULLFT,CYCLICFUNC_MODE_RESTART}
-  cyclicfunc_mode_t;
+typedef enum {
+    CYCLICFUNC_MODE_NORMAL,
+    CYCLICFUNC_MODE_RESTART
+} cyclicfunc_mode_t;
 
 class Lister
 {
