@@ -1,6 +1,6 @@
 /* normalmode.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2006 Ralf Hoffmann.
+ * Copyright (C) 2001-2007 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -30,6 +30,8 @@
 #include <aguix/stringgadget.h>
 #include <aguix/button.h>
 #include <aguix/request.h>
+#include <aguix/mutex.h>
+#include <aguix/condvar.h>
 #include "listermode.h"
 #include "datei.h"
 #include "copyop.h"
@@ -41,8 +43,9 @@
 #include "nmcopyopdir.hh"
 #include "nmextlist.hh"
 #include "nmspecialsourceext.hh"
-#include <aguix/mutex.h>
-#include <aguix/condvar.h>
+#include "dirfiltersettings.hh"
+#include "dirsortsettings.hh"
+#include "stringmatcher_fnmatch.hh"
 
 class Lister;
 class NMFieldListViewDND;
@@ -201,9 +204,9 @@ public:
   void chmodf(struct NM_chmodorder *cmorder);
   void chownf(struct NM_chownorder *coorder);
   
-  void toggleHiddenE();
-  void setShowHiddenE(bool);
-  char *getCurrentDir();
+  void toggleHidden();
+  void setShowHidden(bool);
+  const char *getCurrentDir();
   static bool isCorrectViewProg(const char *str);
   
   typedef enum {NM_GETFILES_ONLYACTIVE,
@@ -277,6 +280,11 @@ public:
                          const mode_t wanted_mode,
                          struct NM_copyorder *copyorder );
   NM_specialsourceExt *getSpecialsourceForFE( const FileEntry *searchfe );
+
+  void activateEntry( const std::string &name );
+
+  bool filteredSearchActive() const;
+  void deactivateFilteredSearch();
 protected:
   /*
    * NM_specialsourceInt always stores a pointer to a FE
@@ -296,15 +304,11 @@ protected:
   };
 
   void reconf( int nx, int ny, int nw, int nh, bool force = false );
-  void buildLister();
+  void buildListView();
   void deleteCache();
-  void deleteFilters();
   void showcache(int);
   void showCacheAbs( int pos );
-  void checkFilters( NMCacheEntry* );
   void showCacheState();
-  void toggleHidden();
-  void setShowHidden(bool);
   void startAction(FileEntry*);
   
   typedef enum {NM_NEWNAME_OK,
@@ -346,18 +350,14 @@ protected:
   NMCacheEntry *ce;
   int stored_cacheentry;
   List *cache;
-  List *filters;
-  bool showHidden;
   Requester *req;
   #define BUFSIZE 128*1024
   void *buf;
   bool searchmodeon;
-  bool searchmode_ignore_case;
   char *oldstr;
   char *lastsearch;
   std::list<const FileEntry*> *copy_deletefe_list;
   int sortmode;
-  int filterlfdnr;
   
   bool showfreespace;
   int updatetime;
@@ -368,7 +368,7 @@ protected:
   
   struct timeval lastclick;
   int lastrow;
-  void removeEntry(FileEntry *fe, int row,bool quick);
+  void removeEntry( FileEntry *fe, int row );
   void fixSpecialSourceList( const std::list<NM_specialsourceInt*> *l, int deleted_row );
   char *parseComStr( const char *sstr,class NM_externorder *extorder,int maxlen, NMExtList *entries[2], bool quote );
   void deselect( FileEntry *fe, int row );
@@ -376,27 +376,11 @@ protected:
   void startsearchmode();
   void finishsearchmode();
 
-  /**
-   * jumps to the first matching entry starting from the active
-   */
-  bool showfirstentry(const char *str);
-
-  /**
-   * jumps to the next entry matching the last search string
-   */
-  bool shownextentry( bool reverse_search = false );
-
   /**
    * jumps to the next entry matching the given string or the last search
    * string (if tstr == NULL )
    */
-  bool shownextentry( const char *tstr, bool reverse_search = false );
-
-  /**
-   * jumps to the next entry matching the given string starting at given
-   * position
-   */
-  bool shownextentry( const char *str, int pos, bool reverse_search = false );
+  bool shownextentry( const char *tstr, bool reverse_search = false, bool start_at_same = false );
 
   typedef struct changemod_info{
     changemod_info();
@@ -419,11 +403,11 @@ protected:
   int applyNewOwner( const NM_specialsourceInt *ss1, uid_t newuid, gid_t newgid );
 
   int requestNewMode(FileEntry *fe,mode_t *return_mode);
-  void setFilters(List*);
-  void configureFilters(bool*,List*);
-  void setLVC4Filter( FieldListView *filv, int row, NM_Filter *fi);
-  int configureFilter(NM_Filter *fi);
-  void checkRebuild( NMCacheEntry *ce, bool forcerebuild );
+  void setFilters( const std::list<NM_Filter> &filters );
+  void configureFilters( bool * tshowhidden, std::list<NM_Filter> &filters );
+  void setLVC4Filter( FieldListView *filv, int row, NM_Filter &fi);
+  int configureFilter( NM_Filter &fi );
+  void rebuildView();
   void setName();
   void updateName();
   void showFreeSpace(bool force);
@@ -432,6 +416,7 @@ protected:
   void setUpdatetime(int nv);
   void setSSHAllow( enum ssh_allow_t nv );
   void setQuicksearchEnabled( bool nv );
+  void setFilteredSearchEnabled( bool nv );
   
   static int maxfilestrlen,maxdirstrlen,maxbytesstrlen,maxwbytesstrlen,maxnochanges;
   
@@ -603,7 +588,6 @@ protected:
   bool isColumnVisible( const WorkerTypes::listcol_t c );
   bool visChanged;
   int oldlvy;
-  FileEntry *findFileEntryForData( int data, int startpos = -1 );
   
   void showInvalidList( ArrayList *list, const char *descr );
   void changeSortModeForField( int field );
@@ -655,6 +639,28 @@ protected:
   bool quicksearch_enabled;
 
   void makeRowActive( int row );
+  void makeListViewRowActive( int row );
+
+  DirFilterSettings _dir_filter_sets;
+  DirSortSettings _dir_sort_sets;
+
+  bool checkEnterDir( const char *dir2 );
+
+  FileEntry *getFEForRow( int row );
+  int _lv_ids_serial;
+
+  StringMatcherFNMatch _entrysearch_matcher;
+  void setEntrySearchString( const std::string &str, bool update_lv = true );
+  std::string getEntrySearchString();
+  void setEntrySearchCaseSensitive( bool nv );
+  
+  void updateDirFilter();
+
+  bool _filtered_search_enabled;
+  bool m_filtered_search_active;
+
+  int buildSpecialSourceIntList( const std::list<NM_specialsourceExt*> &inlist,
+                                 std::list<NM_specialsourceInt*> &outlist );
 };
 
 class NMFieldListViewDND:public FieldListViewDND
