@@ -1,6 +1,6 @@
 /* partspace.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2005 Ralf Hoffmann.
+ * Copyright (C) 2001-2006 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,52 +18,40 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: partspace.cc,v 1.15 2005/02/09 21:46:19 ralf Exp $ */
 
 #include "partspace.h"
 
-#ifdef WANT_THREADS
 void *PS_slavestart( void *arg )
 {
   PartSpace *ps = (PartSpace*)arg;
   ps->slavehandler();
   return NULL;
 }
-#endif
 
 PartSpace::PartSpace()
 {
-#ifdef WANT_THREADS
   spaceinfo = new List();
   spacerequest = new SpaceRequestList();
   spaceanswer = new SpaceRequestList();
 
   slave.running = 0;
   slave.stop = false;
-  if ( pthread_create( &slave.th, NULL, PS_slavestart, this ) == 0 ) {
-    thread_usage = true;
-  } else {
-    fprintf( stderr, "Worker: Can't create thread, disabling thread-support!\n" );
-    thread_usage = false;
+  if ( pthread_create( &slave.th, NULL, PS_slavestart, this ) != 0 ) {
+    fprintf( stderr, "Worker: Can't create thread, aborting!\n" );
+    exit( EXIT_FAILURE );
   }
-#else
-  thread_usage = false;
-#endif
   info_lifetime = 10.0;  // force update after this time
   spaceinfo_maxsize = 100;
 }
 
 PartSpace::~PartSpace()
 {
-#ifdef WANT_THREADS
   SpaceRequestList::space_request_list_t *te;
 
   slave.stop = true;
   // wake up slave
   spacerequest->signal();
-  if ( thread_usage == true ) {
-    pthread_join( slave.th, NULL );
-  }
+  pthread_join( slave.th, NULL );
   while ( spaceanswer->isEmpty_locked() == false ) {
     te = spaceanswer->remove_locked();
     if ( te != NULL ) {
@@ -90,7 +78,6 @@ PartSpace::~PartSpace()
     te = (SpaceRequestList::space_request_list_t*)spaceinfo->getFirstElement();
   }
   delete spaceinfo;
-#endif
 }
 
 // So arbeitet es im Thread-Fall
@@ -113,7 +100,6 @@ PartSpace::~PartSpace()
 
 int PartSpace::readSpace( const char* name )
 {
-#ifdef WANT_THREADS
   SpaceRequestList::space_request_list_t *te, *searchte;
   time_t ct;
   int id;
@@ -126,65 +112,63 @@ int PartSpace::readSpace( const char* name )
   name_device = buf1.st_dev;
 
   ct = time( NULL );
-  if ( thread_usage == true ) {
-    spaceanswer->lock();
-    while ( spaceanswer->isEmpty_locked() == false ) {
-      te = spaceanswer->remove_locked();
-      if ( te != NULL ) {
-        if ( /*te->error*/ 0 == 0 ) {
-          // valid
-	  // currently I accept even invalid entries as the VFS
-	  // doesn't support statvfs but I don't want to
-	  // start asking again and again
+  spaceanswer->lock();
+  while ( spaceanswer->isEmpty_locked() == false ) {
+    te = spaceanswer->remove_locked();
+    if ( te != NULL ) {
+      if ( /*te->error*/ 0 == 0 ) {
+        // valid
+        // currently I accept even invalid entries as the VFS
+        // doesn't support statvfs but I don't want to
+        // start asking again and again
 
-          // search for the same and remove it
-          id = spaceinfo->initEnum();
-          searchte = (SpaceRequestList::space_request_list_t*)spaceinfo->getFirstElement( id );
-          while ( searchte != NULL ) {
-            if ( searchte->device == te->device ) {
-              spaceinfo->removeElement( searchte);
-              _freesafe( searchte->name );
-              delete searchte;
-              break;
-            }
-            searchte = (SpaceRequestList::space_request_list_t*)spaceinfo->getNextElement( id );
+        // search for the same and remove it
+        id = spaceinfo->initEnum();
+        searchte = (SpaceRequestList::space_request_list_t*)spaceinfo->getFirstElement( id );
+        while ( searchte != NULL ) {
+          if ( searchte->device == te->device ) {
+            spaceinfo->removeElement( searchte);
+            _freesafe( searchte->name );
+            delete searchte;
+            break;
           }
-          spaceinfo->closeEnum( id );
-
-          spaceinfo->addElement( te );
-        } else {
-          // invalid
-          _freesafe( te->name );
-          delete te;
+          searchte = (SpaceRequestList::space_request_list_t*)spaceinfo->getNextElement( id );
         }
-      }
-    }
-    spaceanswer->unlock();
-    
-    id = spaceinfo->initEnum();
-  
-    // remove oldest entries if there are too many entries
-    if ( spaceinfo_maxsize > 0 ) {
-      while( spaceinfo->size() > spaceinfo_maxsize ) {
-	te = (SpaceRequestList::space_request_list_t*)spaceinfo->getFirstElement( id );
-	if ( te == NULL ) break;
-	spaceinfo->removeFirstElement();
-	_freesafe( te->name );
-	delete te;
-      }
-    }
+        spaceinfo->closeEnum( id );
 
-    // find name
-    te = (SpaceRequestList::space_request_list_t*)spaceinfo->getFirstElement( id );
-    while ( te != NULL ) {
-      if ( name_device == te->device ) {
-        // entry found
-        break;
+        spaceinfo->addElement( te );
+      } else {
+        // invalid
+        _freesafe( te->name );
+        delete te;
       }
-      te = (SpaceRequestList::space_request_list_t*)spaceinfo->getNextElement( id );
     }
-    spaceinfo->closeEnum( id );
-  } else te = NULL;
+  }
+  spaceanswer->unlock();
+    
+  id = spaceinfo->initEnum();
+  
+  // remove oldest entries if there are too many entries
+  if ( spaceinfo_maxsize > 0 ) {
+    while( spaceinfo->size() > spaceinfo_maxsize ) {
+      te = (SpaceRequestList::space_request_list_t*)spaceinfo->getFirstElement( id );
+      if ( te == NULL ) break;
+      spaceinfo->removeFirstElement();
+      _freesafe( te->name );
+      delete te;
+    }
+  }
+
+  // find name
+  te = (SpaceRequestList::space_request_list_t*)spaceinfo->getFirstElement( id );
+  while ( te != NULL ) {
+    if ( name_device == te->device ) {
+      // entry found
+      break;
+    }
+    te = (SpaceRequestList::space_request_list_t*)spaceinfo->getNextElement( id );
+  }
+  spaceinfo->closeEnum( id );
   
   blocksize = 0;
   space = 0;
@@ -214,68 +198,16 @@ int PartSpace::readSpace( const char* name )
 
   if ( ( te == NULL ) || ( do_update == true ) ) {  
     // not found
-    if ( thread_usage == true ) {
-      // when using thread put a request in the list
-      te = new SpaceRequestList::space_request_list_t;
-      te->name = dupstring( name );
-      te->device = name_device;
-      spacerequest->lock();
-      spacerequest->put_locked( te );
-      spacerequest->signal();
-      spacerequest->unlock();
-      if ( do_update == true ) return 0;  // we found it and fill the variables but want to reload
-      else return EAGAIN;
-    } else {
-      // not using threads so just call getSpace
-      SpaceRequestList::space_request_list_t te2;
-      int erg;
-      
-      erg = getSpace( name, &( te2.fsstatistic ) );
-      if ( erg == 0 ) {
-#ifdef HAVE_STATVFS
-        blocksize = te2.fsstatistic.f_frsize;
-        space = te2.fsstatistic.f_blocks;
-        freespace = te2.fsstatistic.f_bavail;
-#elif defined( HAVE_STATFS )
-        blocksize = te2.fsstatistic.f_bsize;
-        space = te2.fsstatistic.f_blocks;
-        freespace = te2.fsstatistic.f_bavail;
-#else
-        blocksize = 0;
-        space = 0;
-        freespace = 0;
-#endif
-        return 0;
-      } else return erg;
-    }
+    te = new SpaceRequestList::space_request_list_t;
+    te->name = dupstring( name );
+    te->device = name_device;
+    spacerequest->lock();
+    spacerequest->put_locked( te );
+    spacerequest->signal();
+    spacerequest->unlock();
+    if ( do_update == true ) return 0;  // we found it and fill the variables but want to reload
+    else return EAGAIN;
   } else return 0;  // found and not too old
-#else
-
-#ifdef HAVE_STATVFS
-  worker_struct_statvfs fsstatistic;
-#elif defined( HAVE_STATFS )
-  struct statfs fsstatistic;
-#else
-  int fsstatistic;
-#endif
-
-  if ( getSpace( name, &fsstatistic ) == 0 ) {
-#ifdef HAVE_STATVFS
-    blocksize = fsstatistic.f_frsize;
-    space = fsstatistic.f_blocks;
-    freespace = fsstatistic.f_bavail;
-#elif defined( HAVE_STATFS )
-    blocksize = fsstatistic.f_bsize;
-    space = fsstatistic.f_blocks;
-    freespace = fsstatistic.f_bavail;
-#else
-    blocksize = 0;
-    space = 0;
-    freespace = 0;
-#endif
-    return 0;
-  } else return EFAULT;
-#endif
 }
 
 loff_t PartSpace::getBlocksize()
@@ -351,7 +283,6 @@ loff_t PartSpace::getSpaceH(char **unit_return)
   return (loff_t)dsize;
 }
 
-#ifdef WANT_THREADS
 bool PartSpace::SpaceRequestList::isEmpty_locked()
 {
   if ( elements < 1 ) return true;
@@ -478,7 +409,6 @@ void PartSpace::slavehandler()
   printf("leaving slave handler\n");
 #endif
 }
-#endif
 
 #ifdef HAVE_STATVFS
 int PartSpace::getSpace( const char *name, worker_struct_statvfs *statbuf )
