@@ -1,6 +1,6 @@
 /* searchop.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2006 Ralf Hoffmann.
+ * Copyright (C) 2006-2007 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -54,7 +54,8 @@ SearchOp::SearchOp() : FunctionProto(),
                        _matchcontent_sg( NULL ),
                        _matchcontent_case_cb( NULL ),
                        _follow_symlinks_cb( NULL ),
-                       _search_vfs_cb( NULL )
+                       _search_vfs_cb( NULL ),
+                       _search_started( false )
 {
   _edit_command = DEFAULT_EDIT_COMMAND;
   _show_prev_results = false;
@@ -126,6 +127,7 @@ SearchOp::run( WPUContext *wpu, ActionMessage *msg )
     }
   }
 
+  initColorDefs();
 
   win = new AWindow( aguix, 10, 10, 10, 10, 0, getDescription() );
   win->create();
@@ -161,7 +163,7 @@ SearchOp::run( WPUContext *wpu, ActionMessage *msg )
                                                                       catalog.getLocale( 502 ), LABEL_RIGHT, 1, 0 ), 1, 0, AContainer::CFIXNR );
   _matchname_fullpath_cb = (ChooseButton*)ac1_2->add( new ChooseButton( aguix, 0, 0, false,
                                                                         catalog.getLocale( 570 ), LABEL_RIGHT, 1, 0 ), 2, 0, AContainer::CFIXNR );
-  _matchname_case_cb = (ChooseButton*)ac1_2->add( new ChooseButton( aguix, 0, 0, true,
+  _matchname_case_cb = (ChooseButton*)ac1_2->add( new ChooseButton( aguix, 0, 0, false,
                                                                     catalog.getLocale( 725 ), LABEL_RIGHT, 1, 0 ), 3, 0, AContainer::CFIXNR );
   _matchname_regexp_cb->resize( _matchname_sg->getHeight(), _matchname_sg->getHeight() );
   _matchname_fullpath_cb->resize( _matchname_sg->getHeight(), _matchname_sg->getHeight() );
@@ -214,6 +216,7 @@ SearchOp::run( WPUContext *wpu, ActionMessage *msg )
   _resultlv->setShowHeader( true );
   _resultlv->setAcceptFocus( true );
   _resultlv->setDisplayFocus( true );
+  _resultlv->setMBG( wconfig->getListerBG() );
 
   AContainer *ac1_4 = ac1_res->add( new AContainer( win, 4, 1 ), 0, 1 );
   ac1_4->setMinSpace( 0 );
@@ -253,6 +256,7 @@ SearchOp::run( WPUContext *wpu, ActionMessage *msg )
   _storelv->setShowHeader( true );
   _storelv->setAcceptFocus( true );
   _storelv->setDisplayFocus( true );
+  _storelv->setMBG( wconfig->getListerBG() );
 
   Button *clearstoreb =(Button*)ac1_res_store->add( new Button( aguix, 0, 0, catalog.getLocale( 738 ), 1, 0, 0 ), 0, 2, AContainer::CINCW );
 
@@ -333,7 +337,7 @@ SearchOp::run( WPUContext *wpu, ActionMessage *msg )
   if ( _show_prev_results == true ) {
     _resultlv->takeFocus();
   } else {
-    _startdir_sg->takeFocus();
+    _matchname_sg->takeFocus();
   }
   win->useStippleBackground();
 
@@ -406,9 +410,17 @@ SearchOp::run( WPUContext *wpu, ActionMessage *msg )
           break;
         case AG_STRINGGADGET_OK:
           if ( agmsg->stringgadget.sg == _startdir_sg ) {
-            _matchname_sg->takeFocus();
+              if ( agmsg->stringgadget.keystate == ControlMask ) {
+                  startSearch();
+              } else {
+                  _matchname_sg->takeFocus();
+              }
           } else if ( agmsg->stringgadget.sg == _matchname_sg ) {
-            _matchcontent_sg->takeFocus();
+              if ( agmsg->stringgadget.keystate == ControlMask ) {
+                  startSearch();
+              } else {
+                  _matchcontent_sg->takeFocus();
+              }
           } else if ( agmsg->stringgadget.sg == _matchcontent_sg ) {
             startSearch();
           }
@@ -419,6 +431,8 @@ SearchOp::run( WPUContext *wpu, ActionMessage *msg )
             if ( _resultlv->isValidRow( row ) == true ) {
               endmode = 2;
             }
+          } else if ( agmsg->key.key == XK_Return && KEYSTATEMASK( agmsg->key.keystate ) == ControlMask ) {
+              startSearch();
           } else if ( agmsg->key.key == XK_Escape ) {
             endmode = 1;
           } else if ( agmsg->key.key == XK_F3 ) {
@@ -434,9 +448,17 @@ SearchOp::run( WPUContext *wpu, ActionMessage *msg )
       }
       aguix->ReplyMessage( agmsg );
     } else {
-      if ( _sth == NULL || _sth->getCurrentMode() == SearchThread::FINISHED )
+      if ( _sth == NULL || _sth->getCurrentMode() == SearchThread::FINISHED ) {
         prepareButton( *startb, BUTTON_IDLE );
-      else if ( _sth->getCurrentMode() == SearchThread::SEARCHING )
+
+        /* the thread is finished so update store to show total nr of results
+         * but only after all results are gathered */
+        if ( _search_started == true &&
+             ( _sth == NULL || _sth->getNrOfResults() == 0 ) ) {
+            buildStoreLV();
+            _search_started = false;
+        }
+      } else if ( _sth->getCurrentMode() == SearchThread::SEARCHING )
         prepareButton( *startb, BUTTON_SUSPEND );
       else if ( _sth->getCurrentMode() == SearchThread::SUSPENDED )
         prepareButton( *startb, BUTTON_CONTINUE );
@@ -445,7 +467,8 @@ SearchOp::run( WPUContext *wpu, ActionMessage *msg )
         updateState( *state_text );
 
       if ( _sth != NULL && _sth->getNrOfResults() > 0 ) {
-        gatherResults();
+        // don't get more than 10 results at once to keep Worker responsive
+        gatherResults( 10 );
       } else waittime( 10 );
     }
   }
@@ -553,10 +576,16 @@ bool SearchOp::consumeResult( SearchThread::SearchResult &result, FieldListView
     lv.setText( row, 0, "" );
   }
 
-  if ( result.getIsDir() == true )
+  if ( result.getIsDir() == true && fullname != "/" )
     fullname += "/";
   
   lv.setText( row, 2, fullname );
+
+  if ( result.getIsDir() == true ) {
+    lv.setColor( row, dircol );
+  } else {
+    lv.setColor( row, filecol );
+  }
   
   if ( _last_result != fullname ) {
     new_result = true;
@@ -641,7 +670,7 @@ void SearchOp::buildStoreLV()
           it != _stored_results.end();
           it++ ) {
       row = _storelv->addRow();
-      _storelv->setPreColors( row, FieldListView::PRECOLOR_ONLYACTIVE );
+      _storelv->setColor( row, resultcol );
 
       SearchSettings sets = (*it)->getSearchSettings();
       std::string resstr;
@@ -770,6 +799,8 @@ void SearchOp::startSearch()
 
   storeSearchSettings();
   buildStoreLV();
+  
+  _search_started = true;
 }
 
 void SearchOp::stopSearch()
@@ -784,7 +815,7 @@ void SearchOp::stopSearch()
   }
 }
 
-void SearchOp::gatherResults()
+void SearchOp::gatherResults( int get_number_of_results )
 {
   // get results from thread and put them into rst
   //TODO wait for a couple of results or idling search thread
@@ -797,6 +828,12 @@ void SearchOp::gatherResults()
       if ( consumeResult( erg, *_resultlv ) == true ) {
         _rst->getDir()->add( NWC::FSEntry( erg.getFullname() ) );
       }
+
+      if ( get_number_of_results > 0 ) {
+        get_number_of_results--;
+        if ( get_number_of_results == 0 )
+          break;
+      }
     }
     _sth->unlockResults();
     _resultlv->redraw();
@@ -825,7 +862,7 @@ void SearchOp::newSearch()
   }
 
   prepareNewSearch();
-  _startdir_sg->takeFocus();
+  _matchname_sg->takeFocus();
 }
 
 SearchOp::SearchSettings SearchOp::getCurrentSearchSettings()
@@ -976,7 +1013,7 @@ void SearchOp::viewResult()
 
       bool old_sln = FileViewer::getShowLineNumbers();
       FileViewer::setShowLineNumbers( true );
-      FileViewer::view( l, r.getLineNr() );
+      FileViewer::view( l, r.getLineNr(), true );
       FileViewer::setShowLineNumbers( old_sln );
     }
   }
@@ -1155,3 +1192,33 @@ void SearchOp::setShowPrevResults( bool nv )
 {
   _show_prev_results = nv;
 }
+
+void SearchOp::initColorDefs()
+{
+  dircol.setFG( FieldListView::CC_NORMAL, wconfig->getUnselDir( 0 ) );
+  dircol.setBG( FieldListView::CC_NORMAL, wconfig->getUnselDir( 1 ) );
+  dircol.setFG( FieldListView::CC_SELECT, wconfig->getSelDir( 0 ) );
+  dircol.setBG( FieldListView::CC_SELECT, wconfig->getSelDir( 1 ) );
+  dircol.setFG( FieldListView::CC_ACTIVE, wconfig->getUnselDirAct( 0 ) );
+  dircol.setBG( FieldListView::CC_ACTIVE, wconfig->getUnselDirAct( 1 ) );
+  dircol.setFG( FieldListView::CC_SELACT, wconfig->getSelDirAct( 0 ) );
+  dircol.setBG( FieldListView::CC_SELACT, wconfig->getSelDirAct( 1 ) );
+  
+  filecol.setFG( FieldListView::CC_NORMAL, wconfig->getUnselFile( 0 ) );
+  filecol.setBG( FieldListView::CC_NORMAL, wconfig->getUnselFile( 1 ) );
+  filecol.setFG( FieldListView::CC_SELECT, wconfig->getSelFile( 0 ) );
+  filecol.setBG( FieldListView::CC_SELECT, wconfig->getSelFile( 1 ) );
+  filecol.setFG( FieldListView::CC_ACTIVE, wconfig->getUnselFileAct( 0 ) );
+  filecol.setBG( FieldListView::CC_ACTIVE, wconfig->getUnselFileAct( 1 ) );
+  filecol.setFG( FieldListView::CC_SELACT, wconfig->getSelFileAct( 0 ) );
+  filecol.setBG( FieldListView::CC_SELACT, wconfig->getSelFileAct( 1 ) );
+
+  resultcol.setFG( FieldListView::CC_NORMAL, wconfig->getUnselFile( 0 ) );
+  resultcol.setBG( FieldListView::CC_NORMAL, wconfig->getUnselFile( 1 ) );
+  resultcol.setFG( FieldListView::CC_SELECT, wconfig->getUnselFile( 0 ) );
+  resultcol.setBG( FieldListView::CC_SELECT, wconfig->getUnselFile( 1 ) );
+  resultcol.setFG( FieldListView::CC_ACTIVE, wconfig->getUnselFileAct( 0 ) );
+  resultcol.setBG( FieldListView::CC_ACTIVE, wconfig->getUnselFileAct( 1 ) );
+  resultcol.setFG( FieldListView::CC_SELACT, wconfig->getUnselFileAct( 0 ) );
+  resultcol.setBG( FieldListView::CC_SELACT, wconfig->getUnselFileAct( 1 ) );
+}
