@@ -1,6 +1,6 @@
 /* startprogop.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2005 Ralf Hoffmann.
+ * Copyright (C) 2001-2007 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: startprogop.cc,v 1.32 2005/10/19 17:59:18 ralf Exp $ */
 
 #include "startprogop.h"
 #include "listermode.h"
@@ -29,8 +28,9 @@
 #include <aguix/acontainerbb.h>
 #include "execlass.h"
 #include "basic_actions.h"
-#include <algorithm>
 #include "wcfiletype.hh"
+#include "avfssupport.hh"
+#include "fileentry.hh"
 
 const char *StartProgOp::name="StartProgOp";
 
@@ -168,73 +168,85 @@ StartProgOp::normalmodestartprog( ActionMessage *am )
   if ( m1->_startmode == StartSettings::STARTPROG ) {
     tmpname = Datei::createTMPName();
     tmpoutput = Datei::createTMPName();
-    removeTMPFiles = true;
-    Datei fp;
-    if ( fp.open( tmpname, "w" ) == 0 ) {
-      fp.putString( "#! /bin/sh\n" );
-      if ( nm1->getCurrentDir() != NULL ) {
-	if ( ( worker_islocal( nm1->getCurrentDir() ) == 1 ) &&
-	     ( m1->_dontcd == false ) ) {
-	  tstr = AGUIX_catTrustedAndUnTrusted( "cd ", nm1->getCurrentDir() );
-	  fp.putString( tstr );
-	  _freesafe( tstr );
-	  fp.putString( "\n" );
-	}
-      }
-      if ( m1->_global == false ) fp.putString( "./" );
+
+    if ( tmpname != NULL && tmpoutput != NULL ) {
+      removeTMPFiles = true;
+      Datei fp;
+      if ( fp.open( tmpname, "w" ) == 0 ) {
+        fp.putString( "#! /bin/sh\n" );
+        if ( nm1->getCurrentDir() != NULL ) {
+          if ( ( worker_islocal( nm1->getCurrentDir() ) == 1 ) &&
+               ( m1->_dontcd == false ) ) {
+            tstr = AGUIX_catTrustedAndUnTrusted( "cd ", nm1->getCurrentDir() );
+            fp.putString( tstr );
+            _freesafe( tstr );
+            fp.putString( "\n" );
+          }
+        }
+        if ( m1->_global == false ) fp.putString( "./" );
       
-      string1 = Worker_secureCommandForShell( m1->_command.c_str() );
-      if ( string1.length() > 0 ) {
-	if ( m1->_start == STARTPROGOP_SHOW_OUTPUT ) {
-	  string1 += " >";
-	  string1 += tmpoutput;
-	}
-	fp.putString( string1.c_str() );
-	fp.putString( "\n" );
-      }
-      if ( ( m1->_start == STARTPROGOP_START_IN_TERMINAL_AND_WAIT4KEY )||
-	   ( m1->_start == STARTPROGOP_START_IN_TERMINAL ) ) {
-	/* in terminal starten */
-	if ( m1->_start == STARTPROGOP_START_IN_TERMINAL_AND_WAIT4KEY ) {
-	  fp.putStringExt( "echo %s\n", catalog.getLocale( 201 ) );
-	  fp.putString( "read x\n" );
-	}
-	exestr = (char*)_allocsafe( strlen( wconfig->getTerminalStr() ) + strlen( tmpname ) + 1 );
-	sprintf( exestr, wconfig->getTerminalStr(), tmpname );
-      } else {
-	exestr = dupstring( tmpname );
-      }
-      if ( m1->_start == STARTPROGOP_SHOW_OUTPUT ) {
-	useint = true;
-	if ( m1->_view_str.length() > 2 )
-	  if ( strstr( m1->_view_str.c_str(), "%s" ) != NULL ) useint = false;
-	if ( useint == true ) fp.putStringExt( OUTPUT_BIN, tmpoutput );
-	else fp.putStringExt( m1->_view_str.c_str(), tmpoutput );
-	fp.putString( "\n" );
-      }
-      fp.close();
+        string1 = Worker_secureCommandForShell( m1->_command.c_str() );
+        if ( string1.length() > 0 ) {
+          if ( m1->_start == STARTPROGOP_SHOW_OUTPUT ) {
+            string1 += " >";
+            string1 += tmpoutput;
+          }
+          fp.putString( string1.c_str() );
+          fp.putString( "\n" );
+        }
+        if ( ( m1->_start == STARTPROGOP_START_IN_TERMINAL_AND_WAIT4KEY )||
+             ( m1->_start == STARTPROGOP_START_IN_TERMINAL ) ) {
+          /* in terminal starten */
+          if ( m1->_start == STARTPROGOP_START_IN_TERMINAL_AND_WAIT4KEY ) {
+            fp.putStringExt( "echo %s\n", catalog.getLocale( 201 ) );
+            fp.putString( "read x\n" );
+          }
+          exestr = (char*)_allocsafe( strlen( wconfig->getTerminalStr() ) + strlen( tmpname ) + 1 );
+          sprintf( exestr, wconfig->getTerminalStr(), tmpname );
+        } else {
+          exestr = dupstring( tmpname );
+        }
+        if ( m1->_start == STARTPROGOP_SHOW_OUTPUT ) {
+          useint = true;
+          if ( m1->_view_str.length() > 2 )
+            if ( strstr( m1->_view_str.c_str(), "%s" ) != NULL ) useint = false;
+          if ( useint == true ) fp.putStringExt( OUTPUT_BIN, tmpoutput );
+          else fp.putStringExt( m1->_view_str.c_str(), tmpoutput );
+          fp.putString( "\n" );
+        }
+        fp.close();
 
-      if ( fp.errors() == 0 ) {
-	worker_chmod( tmpname, 0700 );
-	removeTMPFiles = false;
-	am->getWorker()->runCommand( exestr, tmpname, tmpoutput, m1->_inbackground );
-      } else {
-	Requester req( Worker::getAGUIX() );
-        char *textstr = (char*)_allocsafe( strlen( catalog.getLocale( 647 ) ) + strlen( tmpname ) + 1 );
+        if ( fp.errors() == 0 ) {
+          worker_chmod( tmpname, 0700 );
+          removeTMPFiles = false;
+          am->getWorker()->runCommand( exestr, tmpname, tmpoutput, m1->_inbackground );
+        } else {
+          Requester req( Worker::getAGUIX() );
+          char *textstr = (char*)_allocsafe( strlen( catalog.getLocale( 647 ) ) + strlen( tmpname ) + 1 );
 
-        sprintf( textstr, catalog.getLocale( 647 ), tmpname );
-	std::string button = catalog.getLocale( 11 );
-	req.request( catalog.getLocale( 347 ), textstr, button.c_str() );
-        _freesafe( textstr );
+          sprintf( textstr, catalog.getLocale( 647 ), tmpname );
+          std::string button = catalog.getLocale( 11 );
+          req.request( catalog.getLocale( 347 ), textstr, button.c_str() );
+          _freesafe( textstr );
+        }
+        _freesafe( exestr );
       }
-      _freesafe( exestr );
+      if ( removeTMPFiles == true ) {
+        worker_unlink( tmpname );
+        worker_unlink( tmpoutput );
+      }
+    } else {
+      Requester req( Worker::getAGUIX() );
+      char *textstr = (char*)_allocsafe( strlen( catalog.getLocale( 647 ) ) + strlen( "" ) + 1 );
+      
+      sprintf( textstr, catalog.getLocale( 647 ), "" );
+      std::string button = catalog.getLocale( 11 );
+      req.request( catalog.getLocale( 347 ), textstr, button.c_str() );
+      _freesafe( textstr );
     }
-    if ( removeTMPFiles == true ) {
-      worker_unlink( tmpname );
-      worker_unlink( tmpoutput );
-    }
-    _freesafe( tmpname );
-    _freesafe( tmpoutput );
+    
+    if ( tmpname != NULL ) _freesafe( tmpname );
+    if ( tmpoutput != NULL ) _freesafe( tmpoutput );
   } else if ( m1->_startmode == StartSettings::HANDLE_TYPE ) {
     WCFiletype *ft = m1->_type;
     if ( ( ft != NULL ) && ( tfe != NULL ) ) {
@@ -874,29 +886,6 @@ StartProgOp::FiletypeWindow::~FiletypeWindow()
   if ( _flatlist != NULL ) delete _flatlist;
 }
 
-std::string find_next_vfs_handler( std::string &searchstr, std::string::size_type &pos )
-{
-  std::string res = "";
-  std::string::size_type pos2;
-
-  pos = searchstr.find_first_of( "0123456789", pos );
-  if ( pos != std::string::npos ) {
-    pos = searchstr.find_first_of( " \t", pos );
-    if ( pos != std::string::npos ) {
-      pos = searchstr.find_first_not_of( " \t", pos );
-      if ( pos != std::string::npos ) {
-	pos2 = searchstr.find( ":", pos );
-	if ( pos2 != std::string::npos )
-	  res.assign( searchstr, pos, pos2 - pos );
-      }
-    }
-  }
-  if ( pos != std::string::npos ) {
-    pos = searchstr.find( "\n", pos );
-  }
-  return res;
-}
-
 std::auto_ptr< StartProgOp::ArchiveWindow > StartProgOp::buildArcWindow( AWindow *win )
 {
   ArchiveWindow *m1;
@@ -910,11 +899,8 @@ std::auto_ptr< StartProgOp::ArchiveWindow > StartProgOp::buildArcWindow( AWindow
                     AContainer::ACONT_MAXH;
   const int cincwnr = cincw +
                       AContainer::ACONT_NORESIZE;
-  int fd, l, row;
-  std::string::size_type pos;
-  std::string a1, a2;
+  int row;
   std::vector<std::string> v;
-  char buf[128];
   
   AContainer *ac1 = win->setContainer( new AContainerBB( win, 1, 3 ), true );
   ac1->setMinSpace( 5 );
@@ -930,25 +916,7 @@ std::auto_ptr< StartProgOp::ArchiveWindow > StartProgOp::buildArcWindow( AWindow
   lv->setDisplayFocus( true );
   lv->setAcceptFocus( true );
 
-  a1 = "";
-  fd = worker_open( "/#avfsstat/modules", O_RDONLY, 0 );
-  if ( fd >= 0 ) {
-    for (;;) {
-      l = worker_read( fd, buf, sizeof( buf ) );
-      if ( l > 0 ) {
-	a1.append( buf, l );
-      } else break;
-    }
-    worker_close( fd );
-  }
-
-  pos = 0;
-  for (;;) {
-    a2 = find_next_vfs_handler( a1, pos );
-    if ( a2.length() < 1 ) break;
-    v.push_back( a2 );
-  }
-  std::sort( v.begin(), v.end() );
+  v = AVFSSupport::getAVFSModules();
 
   for ( std::vector<std::string>::iterator it = v.begin(); it != v.end(); it++ ) {
     row = lv->addRow();
