@@ -251,6 +251,34 @@ public:
   static int getNrOfPreTimes();
   static const char *getPreDate( int pos );
   static const char *getPreTime( int pos );
+
+  class ColorDef
+  {
+  public:
+      ColorDef();
+      ~ColorDef();
+      ColorDef &operator=( const ColorDef &other );
+
+      void setTextViewTextColor( int col );
+      int getTextViewTextColor() const;
+
+      void setTextViewBackground( int col );
+      int getTextViewBackground() const;
+
+      void setTextViewHighlightedFG( int col );
+      int getTextViewHighlightedFG() const;
+
+      void setTextViewHighlightedBG( int col );
+      int getTextViewHighlightedBG() const;
+  private:
+      struct {
+          int textcolor, background;
+          int highlightedfg, highlightedbg;
+      } _textview_colors;
+  };
+
+  void setColorDefs( const ColorDef &cols );
+  ColorDef getColorDefs() const;
 protected:
   char *lang;
   unsigned int rows,columns;
@@ -391,6 +419,8 @@ protected:
   int loadBinDoubleShortkey( Datei *fh, WCDoubleShortkey *dk );
   int loadBinGlobalFlags( Datei *fh );
   List *loadBinFunction( Datei *fh );
+
+  ColorDef _color_defs;
 };
 
 extern WConfig *wconfig;
