@@ -26,6 +26,35 @@
 ColorPanel::ColorPanel( AWindow &basewin, WConfig &baseconfig ) : WConfigPanel( basewin, baseconfig )
 {
   tempconfig = _baseconfig.duplicate();
+
+  sbsb = NULL;
+  sbvb = NULL;
+  sbhb = NULL;
+  slvbsb = NULL;
+  slvbvb = NULL;
+  slvbhb = NULL;
+  ulvbsb = NULL;
+  ulvbvb = NULL;
+  ulvbhb = NULL;
+  lv = NULL;
+
+  for ( int i = 0; i < 10; i++ ) {
+      b[i][0] = NULL;
+      b[i][1] = NULL;
+  }
+
+  cbsb = NULL;
+  cbvb = NULL;
+  cbhb = NULL;
+  rsb = NULL;
+  rvb = NULL;
+  rhb = NULL;
+  _tv_fg_b = NULL;
+  _tv_bg_b = NULL;
+  _tv_hfg_b = NULL;
+  _tv_hbg_b = NULL;
+  _tv_cols_sb = NULL;
+  _tv_high_sb = NULL;
 }
 
 ColorPanel::~ColorPanel()
@@ -42,7 +71,7 @@ int ColorPanel::create()
   
   res = Panel::create();
 
-  AContainer *ac1 = setContainer( new AContainer( this, 1, 11 ), true );
+  AContainer *ac1 = setContainer( new AContainer( this, 1, 13 ), true );
   ac1->setMinSpace( 5 );
   ac1->setMaxSpace( 5 );
   
@@ -256,6 +285,41 @@ int ColorPanel::create()
                              2, 0, AContainer::CFIX );
   rhb->connect( this );
 
+  /*
+   * Code for textview color config
+   */
+
+  ac1->add( new BevelBox( _aguix, 0, 0, 10, 2, 0 ), 0, 11, AContainer::CINCW );
+  
+  AContainer *ac1_7 = ac1->add( new AContainer( this, 3, 2 ), 0, 12 );
+  ac1_7->setBorderWidth( 0 );
+  ac1_7->setMinSpace( 5 );
+  ac1_7->setMaxSpace( 5 );
+
+  WConfig::ColorDef current_cols = _baseconfig.getColorDefs();
+        
+  _tv_cols_sb = (SolidButton*)ac1_7->add( new SolidButton( _aguix, 0, 0, catalog.getLocale( 752 ),
+                                                           current_cols.getTextViewTextColor(),
+                                                           current_cols.getTextViewBackground(), false ),
+                                          0, 0, AContainer::CINCW );
+  _tv_fg_b = (Button*)ac1_7->add( new Button( _aguix, 0, 0, catalog.getLocale( 32 ), 1, 0, 0 ),
+                                  1, 0, AContainer::CFIX );
+  _tv_fg_b->connect( this );
+  _tv_bg_b = (Button*)ac1_7->add( new Button( _aguix, 0, 0, catalog.getLocale( 33 ), 1, 0, 0 ),
+                                  2, 0, AContainer::CFIX );
+  _tv_bg_b->connect( this );
+
+  _tv_high_sb = (SolidButton*)ac1_7->add( new SolidButton( _aguix, 0, 0, catalog.getLocale( 753 ),
+                                                           current_cols.getTextViewHighlightedFG(),
+                                                           current_cols.getTextViewHighlightedBG(), false ),
+                                          0, 1, AContainer::CINCW );
+  _tv_hfg_b = (Button*)ac1_7->add( new Button( _aguix, 0, 0, catalog.getLocale( 32 ), 1, 0, 0 ),
+                                   1, 1, AContainer::CFIX );
+  _tv_hfg_b->connect( this );
+  _tv_hbg_b = (Button*)ac1_7->add( new Button( _aguix, 0, 0, catalog.getLocale( 33 ), 1, 0, 0 ),
+                                   2, 1, AContainer::CFIX );
+  _tv_hbg_b->connect( this );
+
   contMaximize( true );
   return 0;
 }
@@ -291,6 +355,13 @@ int ColorPanel::saveValues()
   _baseconfig.setLVHeader( 0, tempconfig->getLVHeader( 0 ) );
   _baseconfig.setLVHeader( 1, tempconfig->getLVHeader( 1 ) );
   _baseconfig.setListerBG( tempconfig->getListerBG() );
+
+  WConfig::ColorDef current_cols = _baseconfig.getColorDefs();
+  current_cols.setTextViewTextColor( _tv_cols_sb->getFG() );
+  current_cols.setTextViewBackground( _tv_cols_sb->getBG() );
+  current_cols.setTextViewHighlightedFG( _tv_high_sb->getFG() );
+  current_cols.setTextViewHighlightedBG( _tv_high_sb->getBG() );
+  _baseconfig.setColorDefs( current_cols );
   return 0;
 }
 
@@ -367,6 +438,26 @@ void ColorPanel::run( Widget *elem, AGMessage &msg )
         tempconfig->setRequest( 1, col );
         rsb->setBG(col);
       }
+    } else if ( msg.button.button == _tv_fg_b ) {
+        col = tempconfig->palette( _tv_cols_sb->getFG() );
+        if ( col >= 0 ) {
+            _tv_cols_sb->setFG( col );
+        }
+    } else if ( msg.button.button == _tv_bg_b ) {
+        col = tempconfig->palette( _tv_cols_sb->getBG() );
+        if ( col >= 0 ) {
+            _tv_cols_sb->setBG( col );
+        }
+    } else if ( msg.button.button == _tv_hfg_b ) {
+        col = tempconfig->palette( _tv_high_sb->getFG() );
+        if ( col >= 0 ) {
+            _tv_high_sb->setFG( col );
+        }
+    } else if ( msg.button.button == _tv_hbg_b ) {
+        col = tempconfig->palette( _tv_high_sb->getBG() );
+        if ( col >= 0 ) {
+            _tv_high_sb->setBG( col );
+        }
     } else {
       for ( int i = 0; i < 10; i++ ) {
         if(msg.button.button==b[i][0]) {
