@@ -1,6 +1,6 @@
 /* worker.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2006 Ralf Hoffmann.
+ * Copyright (C) 2001-2007 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -51,6 +51,8 @@
 #include "wcbutton.hh"
 #include <aguix/utf8.hh>
 #include "workerversion.h"
+#include "nwc_path.hh"
+#include <iostream>
 
 Requester *Worker::req_static=NULL;
 int Worker::argc = 0;
@@ -202,9 +204,11 @@ void Worker::run()
     if(msg!=NULL) {
       switch(msg->type) {
         case AG_CLOSEWINDOW:
-          quit(1);
-          handleSub=false;
-          break;
+            if ( msg->size.window == mainwin->getWindow() ) {
+                quit(1);
+                handleSub=false;
+            }
+            break;
         case AG_SIZECHANGED:
           if(msg->size.window==mainwin->getWindow()) {
             w=msg->size.neww;
@@ -952,7 +956,7 @@ void Worker::about()
   int erg;
   
   tstr = (char*)_allocsafe( 1024 + 3 * A_BYTESFORNUMBER( int ) + strlen( WORKER_COMMENT ) );
-  sprintf(tstr,"Worker %d.%d.%d%s|Copyright (C) 1998 - 2006 Ralf Hoffmann",WORKER_MAJOR,WORKER_MINOR,WORKER_PATCH,WORKER_COMMENT);
+  sprintf(tstr,"Worker %d.%d.%d%s|Copyright (C) 1998 - 2007 Ralf Hoffmann",WORKER_MAJOR,WORKER_MINOR,WORKER_PATCH,WORKER_COMMENT);
   str1 = tstr;
   _freesafe( tstr );
   
@@ -1598,18 +1602,21 @@ void Worker::updateTime(void)
 #ifdef HAVE_SYSINFO
       if(cbm==WConfig::CLOCKBAR_MODE_TIMERAM) {
         sysinfo(&info);
-        freeram=info.freeram;
-        freeswap=info.freeswap;
+        freeram = info.freeram / 1024;
+        freeram *= info.mem_unit;
+        freeswap = info.freeswap / 1024;
+        freeswap *= info.mem_unit;
         
         buffer=(char*)_allocsafe(strlen(str)+
-                                 strlen("  --  %s: %ld KB  -  %s: %ld KB")+
+                                 strlen("  --  %s: %lu KB  -  %s: %lu KB")+
                                  strlen(catalog.getLocale(105))+strlen(catalog.getLocale(106))+
                                  2 * ( A_BYTESFORNUMBER( unsigned long ) ) + 1);
         
         strcpy(buffer,str);
-        sprintf(buffer+strlen(str),"  --  %s: %ld KB  -  %s: %ld KB",catalog.getLocale(105),(long int)freeram/1024,
-                                                       catalog.getLocale(106),
-                                                       (long int)freeswap/1024);
+        sprintf( buffer + strlen( str ),
+                 "  --  %s: %lu KB  -  %s: %lu KB",
+                 catalog.getLocale( 105 ), freeram,
+                 catalog.getLocale( 106 ), freeswap );
       } else {
         buffer=(char*)_allocsafe(strlen(str)+1);
         strcpy(buffer,str);
@@ -1628,7 +1635,7 @@ void Worker::updateTime(void)
 
 void Worker::checkfirststart( char **setlang )
 {
-  char *tstr,*homestr,*filestr;
+  char *homestr,*filestr;
   bool copyconfig=false;
   const char *textstr,*buttonstr;
   int erg;
@@ -1651,56 +1658,10 @@ void Worker::checkfirststart( char **setlang )
       if(erg==0) copyconfig=true;
     }
     if(copyconfig==true) {
-      List *langs = new List();
-      DIR *dir2;
-      std::string catdir, buttonstr2, str2, str3;
-      worker_struct_dirent *namelist;
-      int id;
+      std::string catdir, str2, str3;
+      std::string chosen_lang;
 
-      langs->addElement( dupstring( "english" ) );
-      if ( Worker::getDataDir().length() > 0 ) {
-        catdir = Worker::getDataDir();
-        catdir += "/catalogs";
-        dir2 = worker_opendir( catdir.c_str() );
-        if ( dir2 != NULL ) {
-          std::string ending = ".catalog";
-          if ( UTF8::getUTF8Mode() != UTF8::UTF8_DISABLED && UTF8::getCurrentEncoding() == UTF8::ENCODING_UTF8 ) {
-            ending += ".utf8";
-          }
-
-          while ( ( namelist = worker_readdir( dir2 ) ) != NULL ) {
-            if ( strlen( namelist->d_name ) > ending.length() ) {
-              if ( strcmp( ending.c_str(), ( namelist->d_name ) + strlen( namelist->d_name ) - ending.length() ) == 0 ) {
-                // Dies ist ein Katalog
-                tstr = namelist->d_name;
-                tstr[ strlen( tstr ) - ending.length() ] = 0;
-                langs->addElement( dupstring( tstr ) );
-              }
-            }
-          }
-          worker_closedir( dir2 );
-        }
-      }
-      // now all available languages are in the list
-      // build a requester
-      
-      id = langs->initEnum();
-      tstr = (char*)langs->getFirstElement( id );
-      buttonstr2 = "";
-      while ( tstr != NULL ) {
-        if ( buttonstr2.length() > 0 )
-          buttonstr2 += "|";
-        buttonstr2 += tstr;
-        tstr = (char*)langs->getNextElement( id );
-      }
-
-      textstr="Now choose your preferred language (this can be changed later):";
-      erg = req_static->request( "Worker request", textstr, buttonstr2.c_str() );
-      
-      tstr = (char*)langs->getElementAt( id, erg );
-      if ( tstr == NULL ) {
-        tstr = (char*)langs->getFirstElement( id );
-      }
+      chosen_lang = queryLanguage();
 
       catdir = homestr;
       catdir += "/.worker";
@@ -1717,7 +1678,7 @@ void Worker::checkfirststart( char **setlang )
       if ( Worker::getDataDir().length() > 0 ) {
         str2 = Worker::getDataDir();
         str2 += "/config-";
-        str2 += tstr;
+        str2 += chosen_lang;
         if ( UTF8::getUTF8Mode() != UTF8::UTF8_DISABLED && UTF8::getCurrentEncoding() == UTF8::ENCODING_UTF8 ) {
           str2 += ".utf8";
         }
@@ -1733,8 +1694,8 @@ void Worker::checkfirststart( char **setlang )
         
         if ( setlang != NULL ) {
           // if not english remember to set the language later
-          if ( langs->getIndex( tstr ) > 0 )
-            *setlang = dupstring( tstr );
+          if ( chosen_lang != "english" )
+            *setlang = dupstring( chosen_lang.c_str() );
         }
       }
       
@@ -1761,14 +1722,6 @@ void Worker::checkfirststart( char **setlang )
         buttonstr="Ok";
         req_static->request( "Worker error", str3.c_str(), buttonstr );
       }
-      tstr = (char*)langs->getFirstElement( id );
-      while ( tstr != NULL ) {
-        _freesafe( tstr );
-        langs->removeFirstElement();
-        tstr = (char*)langs->getFirstElement( id );
-      }
-      langs->closeEnum( id );
-      delete langs;
     }
     _freesafe(filestr);
   }
@@ -2811,3 +2764,137 @@ int Worker::runCommand( const char*exestr,
   // just for some compiler to compile without warning
   return 0;
 }
+
+std::string Worker::queryLanguage()
+{
+    std::vector<std::string> langs;
+    DIR *dir;
+    std::string catdir, buttonstr2, str2, str3;
+    worker_struct_dirent *namelist;
+    std::string selected_lang;
+
+    selected_lang = "english";
+    
+    langs.push_back( selected_lang );
+    if ( Worker::getDataDir().length() > 0 ) {
+        catdir = Worker::getDataDir();
+        catdir += "/catalogs";
+        dir = worker_opendir( catdir.c_str() );
+        if ( dir != NULL ) {
+            std::string ending = ".catalog";
+            if ( UTF8::getUTF8Mode() != UTF8::UTF8_DISABLED &&
+                 UTF8::getCurrentEncoding() == UTF8::ENCODING_UTF8 ) {
+                ending += ".utf8";
+            }
+            
+            while ( ( namelist = worker_readdir( dir ) ) != NULL ) {
+                if ( strlen( namelist->d_name ) > ending.length() ) {
+                    if ( strcmp( ending.c_str(),
+                                 ( namelist->d_name ) + strlen( namelist->d_name ) - ending.length() ) == 0 ) {
+                        // looks a catalog file
+                        std::string str1( namelist->d_name,
+                                          strlen( namelist->d_name ) - ending.length() );
+                        langs.push_back( str1 );
+                    }
+                }
+            }
+            worker_closedir( dir );
+        }
+    }
+    // now all available languages are in the list
+    // build a requester
+
+    AWindow *win;
+    AGMessage *msg;
+    int endmode=-1;
+    
+    win = new AWindow( aguix, 10, 10, 10, 10, 0, "Language selection" );
+    win->create();
+    
+    AContainer *ac1 = win->setContainer( new AContainer( win, 1, 3 ), true );
+    ac1->setMinSpace( 5 );
+    ac1->setMaxSpace( 5 );
+    
+    ac1->add( new Text( aguix, 0, 0, "Choose your language (this can be changed later):", 1 ),
+              0, 0, AContainer::CINCWNR );
+
+    FieldListView *lv1 = (FieldListView*)ac1->add( new FieldListView( aguix,
+                                                                      0, 0,
+                                                                      200, 200, 0 ),
+                                                   0, 1, AContainer::CMIN );
+    lv1->setHBarState( 2 );
+    lv1->setVBarState( 2 );
+    lv1->setAcceptFocus( true );
+    lv1->setDisplayFocus( true );
+
+    for ( std::vector<std::string>::iterator it1 = langs.begin();
+          it1 != langs.end();
+          it1++ ) {
+        int row = lv1->addRow();
+        lv1->setText( row, 0, *it1 );
+        lv1->setPreColors( row, FieldListView::PRECOLOR_ONLYACTIVE );
+    }
+
+    AContainer *ac1_1 = ac1->add( new AContainer( win, 3, 1 ), 0, 2 );
+    ac1_1->setMinSpace( 5 );
+    ac1_1->setMaxSpace( -1 );
+    ac1_1->setBorderWidth( 0 );
+    Button *contb =(Button*)ac1_1->add( new Button( aguix,
+                                                    0,
+                                                    0,
+                                                    "Continue",
+                                                    1,
+                                                    0,
+                                                    0 ), 1, 0, AContainer::CFIX );
+    win->setDoTabCycling( true );
+    win->contMaximize( true );
+    win->show();
+    
+    for ( ;endmode == -1; ) {
+        msg = aguix->WaitMessage( win );
+        if ( msg != NULL ) {
+            switch ( msg->type ) {
+              case AG_CLOSEWINDOW:
+                  if ( msg->closewindow.window == win->getWindow() ) endmode = 1;
+                  break;
+              case AG_BUTTONCLICKED:
+                  if ( msg->button.button == contb ) endmode = 0;
+                  break;
+            }
+            aguix->ReplyMessage( msg );
+        }
+    }
+    
+    if ( endmode == 0 ) {
+        int row = lv1->getActiveRow();
+        if ( lv1->isValidRow( row ) == true ) {
+            selected_lang = langs[row];
+        }
+    }
+    
+    delete win;
+    return selected_lang;
+}
+
+std::string Worker::getWorkerConfigDir()
+{
+    const char *homestr;
+    std::string d;
+    
+    homestr = getenv( "HOME" );
+    if ( homestr == NULL ) {
+        std::cerr << "Worker: No $HOME found, aborting!" << std::endl;
+        exit( EXIT_FAILURE );
+    }
+
+    d = NWC::Path::join( homestr, ".worker" );
+
+    //TODO the result could be cached
+    if ( Datei::fileExists( d.c_str() ) == false ) {
+        if ( worker_mkdir( d.c_str(), 0700 ) != 0 ) {
+            std::cerr << "Worker: Couldn't create worker configuration directory " << d << std::endl;
+            exit( EXIT_FAILURE );
+        }
+    }
+    return d;
+}
