@@ -1,6 +1,6 @@
 /* worker_locale.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2006 Ralf Hoffmann.
+ * Copyright (C) 2001-2007 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,15 +18,14 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: worker_locale.cc,v 1.175 2006/02/09 21:17:30 ralf Exp $ */
 
 #include "worker_locale.h"
 #include "wconfig.h"
 #include "worker.h"
 #include <aguix/utf8.hh>
 
-#define CATENTRY 752
-#define CATCOMENTRY 51
+#define CATENTRY 768
+#define CATCOMENTRY 52
 #define CATFLAGENTRY 59
 
 WorkerLocale catalog;
@@ -546,7 +545,7 @@ numerical value. So ( \"5\" > \"06\" ) is true while ( 5 > \"06\" ) is false!" )
   catalog[487]=dupstring( "Choose \"Recursive\" too collect all files recursively (for selected dirs)|  This can only be changed as the very first command!|Choose \"With quotes\" if you wan't to use filenames in quotes when replacing flags|\
   This can be changed by any time" );
   catalog[488]=dupstring( "change user window" );
-  catalog[489]=dupstring( "Here you can change the window you can use to show some information to the user.|You can change the progress bar by any string which can contain flags and|you can also use the output\
+  catalog[489]=dupstring( "Here you can change the window to show some information to the user.|You can change the progress bar by any string which can contain flags and|you can also use the output\
  of this string for the progress.|The only limitation is that the resulting string can be transformed to a number between 0 and 100!|You can also change the text shown above the progress\
 bar and this string can contain \\||for a new line (as many as you want). Of course this string can contain any valid flags and|you can also use the output instead." );
   catalog[490]=dupstring( "Change window visibility" );
@@ -853,6 +852,22 @@ match any font." );
   catalog[749]=dupstring( "Cannot continue \"if\" parsing because the following command writes something to stderr\nand I treat this as an error:\n%s\nThe error was:\n" );
   catalog[750]=dupstring( "Cannot push the output of the following command because it writes something to stderr\nand I treat this as an error:\n%s\nThe error was:\n" );
   catalog[751]=dupstring( "I don't update the user window because the following command wrotes something to stderr:\n%s\nThe error was:\n" );
+  catalog[752]=dupstring( "Text view color" );
+  catalog[753]=dupstring( "Text view color for highlighted text" );
+  catalog[754]=dupstring( "Enable filtered search" );
+  catalog[755]=dupstring( "Anonymous login" );
+  catalog[756]=dupstring( "Add \"%s\" to bookmarks." );
+  catalog[757]=dupstring( "Make \"%s\" active when jumping to this bookmark." );
+  catalog[758]=dupstring( "Find as you type:" );
+  catalog[759]=dupstring( "Add bookmark" );
+  catalog[760]=dupstring( "Delete bookmark" );
+  catalog[761]=dupstring( "Jump to directory" );
+  catalog[762]=dupstring( "Do you really want to delete the selected bookmark?" );
+  catalog[763]=dupstring( "Read more" );
+  catalog[764]=dupstring( "The size of the file is %s. Shall I show only the first %s (faster) or|do you want to see the complete file (slower)?|If you choose to view only the first part of the file, you can still read more of it on demand.|If text wrapping was enabled you can also choose to disable it which is much faster when reading large files." );
+  catalog[765]=dupstring( "Read partial file" );
+  catalog[766]=dupstring( "Read complete file" );
+  catalog[767]=dupstring( "Read complete file but disable wrapping" );
 
 //  catalog[]=dupstring( "" );
   
@@ -907,6 +922,7 @@ match any font." );
   catalogcom[48]=dupstring( "FTP connection" );
   catalogcom[49]=dupstring( "Internal text viewer" );
   catalogcom[50]=dupstring( "Search" );
+  catalogcom[51]=dupstring( "Directory bookmarks" );
   
   catalogflag[0]=dupstring( "Stringrequester" );
   catalogflag[1]=dupstring( "path" );
@@ -1047,6 +1063,30 @@ int WorkerLocale::loadLanguage(const char *name)
   return 0;
 }
 
+/* this function replaces backslash n with a real newline
+ * recently I added support for using \n in translations but the
+ * file format doesn't support it natively
+ * Perhaps it's time to switch to getext
+ */
+static char *replaceNewline( const char *buffer )
+{
+    char *res = dupstring( buffer );
+    const char *src;
+    char *dest;
+
+    src = buffer;
+    dest = res;
+    while ( *src != '\0' ) {
+        if ( *src == '\\' && *( src + 1 ) == 'n' ) {
+            *dest++ = '\n';
+            src += 2;
+        } else
+            *dest++ = *src++;
+    }
+    *dest = '\0';
+    return res;
+}
+
 void WorkerLocale::parse(Datei *file,int cat)
 {
   char *buffer=(char*)_allocsafe(128*1024);
@@ -1088,7 +1128,7 @@ void WorkerLocale::parse(Datei *file,int cat)
           buffer[bufpos]=0;
           if(strlen(buffer)>0) {
             // store buffer in entrynr
-            tstr = dupstring( buffer );
+            tstr = replaceNewline( buffer );
             switch(cat) {
               case 0:
                 // normal
